#!/bin/sh
name=$( hostname )

is_lsb=$( lsb_release -sd 2>/dev/null )

if [ -n "${is_lsb}" ]; then
	os="${is_lsb}"
else
	if [ -f /etc/redhat-release ]; then
		os=$( cat /etc/redhat-release | sed 's/\n \l//' | head -n 1 )
	elif [ -f /etc/issue ]; then
		os=$( cat /etc/redhat-release | sed 's/\n \l//' | head -n 1 )
	fi
fi

ips=$( hostname -I | sed 's/^[ \t]*//;s/[ \t]*$//')
CPUName=`cat /proc/cpuinfo | grep 'model name' | head -n 1 | awk '{print ($4, $5, $6, $8, $9, $10)}'`
NCores=$( cat /proc/cpuinfo | grep 'model name' | wc -l )
FREE_MEM=$( free -m | head -n2 | tail -n1 | awk {'print $4'} )
TOTAL_MEM=$( free -m | head -n2 | tail -n1 | awk {'print $2'} )
mem=$( echo $TOTAL_MEM' total / '$FREE_MEM' free' )

if [ -e /tmp/veil_env ]; then
	veilenv=$(cat /tmp/veil_env)
fi

veilinfo=$(cat /etc/puppetveil/code/environments/production/data/veilrole.yaml | cut -d':' -f2)

systemctl status nftables.service 1>/dev/null
if [ $? -ne 0 ]; then
  nft_st="stopped"
else
  nft_st="\033[1;33mrunning\033[0m"
fi

first_ip=$( ip -f inet addr show veil-mgmt 2>/dev/null | awk '/inet / {print $2}' | cut -d/ -f1 )
other_ips=''
for word in $ips; do
  if [ ! -z "$first_ip" ] && [ $word != $first_ip ]; then
    other_ips="${other_ips} ${word}"
  fi
done
result_str="Please use your web browser for convenience:
  web on https://$first_ip/
  cli on https://$first_ip/shell/"
if [ "$other_ips" != '' ]; then
   result_str="${result_str}\nYou can also use other assigned external IPs:$other_ips."
fi

echo "\033[32m------------------: \033[97mSystem Data\033[32m :-------------------------------\033[0m
Hostname:     \033[1;33m$name\033[0m ($ips) `domainname`
Kernel:       `uname -r`
Uptime:      `uptime | sed 's/.*up ([^,]*), .*/1/'`
CPU:          $CPUName ($NCores cores)
Memory(Mb):   $mem
Environment:  $veilenv
Role:        $veilinfo
User:         `whoami`
Firewall:     $nft_st
$result_str
\033[32m----------------------------------------------------------------\033[0m"
