# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`grafana`](#grafana): == Class: grafana  Installs and configures Grafana.  === Parameters [*archive_source*] Download location of tarball to be used with the 'arch
* [`grafana::config`](#grafanaconfig): == Class grafana::config  This class is called from grafana
* [`grafana::install`](#grafanainstall): == Class grafana::install
* [`grafana::service`](#grafanaservice): == Class grafana::service  This class is meant to be called from grafana It ensure the service is running
* [`grafana::validator`](#grafanavalidator): Manage grafana_conn_validator resource

### Resource types

* [`grafana_conn_validator`](#grafana_conn_validator): Verify connectivity to the Grafana API
* [`grafana_dashboard`](#grafana_dashboard): Manage dashboards in Grafana
* [`grafana_dashboard_permission`](#grafana_dashboard_permission): Manage dashboard permissions in Grafana
* [`grafana_datasource`](#grafana_datasource): Manage datasources in Grafana
* [`grafana_folder`](#grafana_folder): Manage folders in Grafana
* [`grafana_ldap_config`](#grafana_ldap_config): Manage Grafana LDAP configuration
* [`grafana_ldap_group_mapping`](#grafana_ldap_group_mapping): Map an LDAP group to a Grafana role.
* [`grafana_ldap_server`](#grafana_ldap_server): Manage Grafana LDAP servers for LDAP authentication.
* [`grafana_membership`](#grafana_membership): Manage resource memberships in Grafana
* [`grafana_notification`](#grafana_notification): Manage notification in Grafana
* [`grafana_organization`](#grafana_organization): Manage organizations in Grafana
* [`grafana_plugin`](#grafana_plugin): manages grafana plugins
* [`grafana_team`](#grafana_team): Manage teams in Grafana
* [`grafana_user`](#grafana_user): Manage users in Grafana

### Functions

* [`grafana::deep_find_and_remove`](#grafanadeep_find_and_remove): == Function: deep_find_and_remove  This function takes a hash as input, along with a string (key). Additionally, the optional removekey (defa
* [`grafana::get_sub_paths`](#grafanaget_sub_paths): == Function get_sub_paths  This function receives an input path as an input parameter, and returns an array of the subpaths in the input, exc

### Tasks

* [`change_grafana_admin_password`](#change_grafana_admin_password): Change the Grafana admin user's password

## Classes

### <a name="grafana"></a>`grafana`

== Class: grafana

Installs and configures Grafana.

=== Parameters
[*archive_source*]
Download location of tarball to be used with the 'archive' install method.
Defaults to the URL of the latest version of Grafana available at the time of module release.

[*container_cfg*]
Boolean. Determines whether a configuration file should be generated when using the 'docker' install method.
If true, use the `cfg` and `cfg_location` parameters to control creation of the file.
Defaults to false.

[*container_params*]
Hash of parameters to use when creating the Docker container. For use with the 'docker' install method.
Refer to documentation of the `docker::run` resource in the `garethr-docker` module for details of available parameters.
Defaults to:

  container_params => {
    'image' => 'grafana/grafana:latest',
    'ports' => '3000'
  }

[*data_dir*]
The directory Grafana will use for storing its data.
Defaults to '/var/lib/grafana'.

[*install_dir*]
Installation directory to be used with the 'archive' install method.
Defaults to '/usr/share/grafana'.

[*install_method*]
Set to 'archive' to install Grafana using the tar archive.
Set to 'docker' to install Grafana using the official Docker container.
Set to 'package' to install Grafana using .deb or .rpm packages.
Set to 'repo' to install Grafana using an apt or yum repository.
Defaults to 'package'.

[*manage_package_repo*]
If true this will setup the official grafana repositories on your host. Defaults to true.

[*package_name*]
The name of the package managed with the 'package' install method.
Defaults to 'grafana'.

[*package_source*]
Download location of package to be used with the 'package' install method.
Defaults to the URL of the latest version of Grafana available at the time of module release.

[*service_name*]
The name of the service managed with the 'archive' and 'package' install methods.
Defaults to 'grafana-server'.

[*version*]
The version of Grafana to install and manage.
Defaults to 'installed'

[*repo_name*]
When using 'repo' install_method, the repo to look for packages in.
Set to 'stable' to install only stable versions
Set to 'beta' to install beta versions
Defaults to stable.

[*plugins*]
A hash of plugins to be passed to `create_resources`, wraps around the
`grafana_plugin` resource.

[*provisioning_dashboards*]
Hash of dashboards to provision into grafana. grafana > v5.0.0
required. Hash will be converted into YAML and used by grafana to
provision dashboards.

[*provisioning_datasources*]
Hash of datasources to provision into grafana, grafana > v5.0.0
required. Hash will be converted into YAML and used by granfana to
configure datasources.

[*provisioning_dashboards_file*]
String with the fully qualified path to place the provisioning file
for dashboards, only used if provisioning_dashboards is specified.
Defaults to '/etc/grafana/provisioning/dashboards/puppetprovisioned.yaml'

[*provisioning_datasources_file*]
String with the fully qualified path to place the provisioning file
for datasources, only used if provisioning_datasources is specified.
Default to '/etc/grafana/provisioning/datasources/puppetprovisioned.yaml'

[*create_subdirs_provisioning*]
Boolean, defaults to false. If true puppet will create any
subdirectories in the given path when provisioning dashboards.

[*sysconfig_location*]
Location of the sysconfig file for the environment of the grafana-server service.
This is only used when the install_method is 'package' or 'repo'.

[*sysconfig*]
A hash of environment variables for the grafana-server service

Example:
  sysconfig => { 'http_proxy' => 'http://proxy.example.com/' }

[*ldap_servers*]
A hash of ldap_servers to be passed to `create_resources`, wraps around the
`grafana_ldap_server` resource.

[*ldap_group_mappings*]
A hash of ldap_servers to be passed to `create_resources`, wraps around the
`grafana_ldap_group_mapping` resource.

[*toml_manage_package*]
ruby-toml is required to generate the TOML-based LDAP config for Grafana.
Defaults to true. Set to false if you manage package- or gem-install
somewhere else.

[*toml_package_name*]
Name of the software-package providing the TOML parser library.
Defaults to ruby-toml.

[*toml_package_ensure*]
Ensure the package-resource - e.g. installed, absent, etc.
https://puppet.com/docs/puppet/latest/types/package.html#package-attribute-ensure
Defaults to present

[*toml_package_provider*]
The package-provider used to install the TOML parser library.
Defaults to undef, to let Puppet decide. See
https://puppet.com/docs/puppet/latest/types/package.html#package-attribute-provider

=== Examples

 class { '::grafana':
   install_method  => 'docker',
 }

#### Parameters

The following parameters are available in the `grafana` class:

* [`archive_source`](#archive_source)
* [`cfg_location`](#cfg_location)
* [`cfg`](#cfg)
* [`ldap_cfg`](#ldap_cfg)
* [`container_cfg`](#container_cfg)
* [`container_params`](#container_params)
* [`docker_image`](#docker_image)
* [`docker_ports`](#docker_ports)
* [`data_dir`](#data_dir)
* [`install_dir`](#install_dir)
* [`install_method`](#install_method)
* [`manage_package_repo`](#manage_package_repo)
* [`package_name`](#package_name)
* [`package_source`](#package_source)
* [`repo_name`](#repo_name)
* [`rpm_iteration`](#rpm_iteration)
* [`service_name`](#service_name)
* [`version`](#version)
* [`plugins`](#plugins)
* [`provisioning_dashboards`](#provisioning_dashboards)
* [`provisioning_datasources`](#provisioning_datasources)
* [`provisioning_dashboards_file`](#provisioning_dashboards_file)
* [`provisioning_datasources_file`](#provisioning_datasources_file)
* [`create_subdirs_provisioning`](#create_subdirs_provisioning)
* [`sysconfig_location`](#sysconfig_location)
* [`sysconfig`](#sysconfig)
* [`ldap_servers`](#ldap_servers)
* [`ldap_group_mappings`](#ldap_group_mappings)
* [`toml_manage_package`](#toml_manage_package)
* [`toml_package_name`](#toml_package_name)
* [`toml_package_ensure`](#toml_package_ensure)
* [`toml_package_provider`](#toml_package_provider)

##### <a name="archive_source"></a>`archive_source`

Data type: `Optional[String]`



##### <a name="cfg_location"></a>`cfg_location`

Data type: `String`



##### <a name="cfg"></a>`cfg`

Data type: `Hash`



##### <a name="ldap_cfg"></a>`ldap_cfg`

Data type: `Optional[Variant[Hash,Array]]`



##### <a name="container_cfg"></a>`container_cfg`

Data type: `Boolean`



##### <a name="container_params"></a>`container_params`

Data type: `Hash`



##### <a name="docker_image"></a>`docker_image`

Data type: `String`



##### <a name="docker_ports"></a>`docker_ports`

Data type: `String`



##### <a name="data_dir"></a>`data_dir`

Data type: `String`



##### <a name="install_dir"></a>`install_dir`

Data type: `String`



##### <a name="install_method"></a>`install_method`

Data type: `String`



##### <a name="manage_package_repo"></a>`manage_package_repo`

Data type: `Boolean`



##### <a name="package_name"></a>`package_name`

Data type: `String`



##### <a name="package_source"></a>`package_source`

Data type: `Optional[String]`



##### <a name="repo_name"></a>`repo_name`

Data type: `Enum['stable', 'beta']`



##### <a name="rpm_iteration"></a>`rpm_iteration`

Data type: `String`



##### <a name="service_name"></a>`service_name`

Data type: `String`



##### <a name="version"></a>`version`

Data type: `String`



##### <a name="plugins"></a>`plugins`

Data type: `Hash`



##### <a name="provisioning_dashboards"></a>`provisioning_dashboards`

Data type: `Hash`



##### <a name="provisioning_datasources"></a>`provisioning_datasources`

Data type: `Hash`



##### <a name="provisioning_dashboards_file"></a>`provisioning_dashboards_file`

Data type: `String`



##### <a name="provisioning_datasources_file"></a>`provisioning_datasources_file`

Data type: `String`



##### <a name="create_subdirs_provisioning"></a>`create_subdirs_provisioning`

Data type: `Boolean`



##### <a name="sysconfig_location"></a>`sysconfig_location`

Data type: `Optional[String]`



##### <a name="sysconfig"></a>`sysconfig`

Data type: `Optional[Hash]`



##### <a name="ldap_servers"></a>`ldap_servers`

Data type: `Hash[String[1], Hash]`



##### <a name="ldap_group_mappings"></a>`ldap_group_mappings`

Data type: `Hash[String[1], Hash]`



##### <a name="toml_manage_package"></a>`toml_manage_package`

Data type: `Boolean`



##### <a name="toml_package_name"></a>`toml_package_name`

Data type: `String[1]`



##### <a name="toml_package_ensure"></a>`toml_package_ensure`

Data type: `String[1]`



##### <a name="toml_package_provider"></a>`toml_package_provider`

Data type: `Optional[String[1]]`



### <a name="grafanaconfig"></a>`grafana::config`

== Class grafana::config

This class is called from grafana

### <a name="grafanainstall"></a>`grafana::install`

== Class grafana::install

### <a name="grafanaservice"></a>`grafana::service`

== Class grafana::service

This class is meant to be called from grafana
It ensure the service is running

### <a name="grafanavalidator"></a>`grafana::validator`

Manage grafana_conn_validator resource

#### Parameters

The following parameters are available in the `grafana::validator` class:

* [`grafana_url`](#grafana_url)
* [`grafana_api_path`](#grafana_api_path)

##### <a name="grafana_url"></a>`grafana_url`

Data type: `Stdlib::HTTPUrl`

Grafana URL.

Default value: `'http://localhost:3000'`

##### <a name="grafana_api_path"></a>`grafana_api_path`

Data type: `Stdlib::Absolutepath`

API path to validate with.

Default value: `'/api/health'`

## Resource types

### <a name="grafana_conn_validator"></a>`grafana_conn_validator`

Verify connectivity to the Grafana API

#### Properties

The following properties are available in the `grafana_conn_validator` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `grafana_conn_validator` type.

* [`grafana_api_path`](#grafana_api_path)
* [`grafana_url`](#grafana_url)
* [`name`](#name)
* [`provider`](#provider)
* [`timeout`](#timeout)

##### <a name="grafana_api_path"></a>`grafana_api_path`

The absolute path to the API endpoint

Default value: `/api/health`

##### <a name="grafana_url"></a>`grafana_url`

The URL of the Grafana server

Default value: `http://localhost:3000`

##### <a name="name"></a>`name`

namevar

Arbitrary name of this resource

##### <a name="provider"></a>`provider`

The specific backend to use for this `grafana_conn_validator` resource. You will seldom need to specify this --- Puppet
will usually discover the appropriate provider for your platform.

##### <a name="timeout"></a>`timeout`

How long to wait for the API to be available

Default value: `20`

### <a name="grafana_dashboard"></a>`grafana_dashboard`

Manage dashboards in Grafana

#### Properties

The following properties are available in the `grafana_dashboard` type.

##### `content`

The JSON representation of the dashboard.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `grafana_dashboard` type.

* [`folder`](#folder)
* [`grafana_api_path`](#grafana_api_path)
* [`grafana_password`](#grafana_password)
* [`grafana_url`](#grafana_url)
* [`grafana_user`](#grafana_user)
* [`organization`](#organization)
* [`provider`](#provider)
* [`title`](#title)

##### <a name="folder"></a>`folder`

The folder to place the dashboard in (optional)

##### <a name="grafana_api_path"></a>`grafana_api_path`

The absolute path to the API endpoint

Default value: `/api`

##### <a name="grafana_password"></a>`grafana_password`

The password for the Grafana server (optional)

##### <a name="grafana_url"></a>`grafana_url`

The URL of the Grafana server

Default value: `''`

##### <a name="grafana_user"></a>`grafana_user`

The username for the Grafana server (optional)

##### <a name="organization"></a>`organization`

The organization name to create the datasource on

Default value: `1`

##### <a name="provider"></a>`provider`

The specific backend to use for this `grafana_dashboard` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="title"></a>`title`

The title of the dashboard.

### <a name="grafana_dashboard_permission"></a>`grafana_dashboard_permission`

Manage dashboard permissions in Grafana

#### Properties

The following properties are available in the `grafana_dashboard_permission` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `permission`

Valid values: `Admin`, `Edit`, `View`

The role to apply

#### Parameters

The following parameters are available in the `grafana_dashboard_permission` type.

* [`dashboard`](#dashboard)
* [`grafana_api_path`](#grafana_api_path)
* [`grafana_password`](#grafana_password)
* [`grafana_url`](#grafana_url)
* [`grafana_user`](#grafana_user)
* [`name`](#name)
* [`organization`](#organization)
* [`provider`](#provider)
* [`team`](#team)
* [`user`](#user)

##### <a name="dashboard"></a>`dashboard`

Dashboard to modify permissions for

##### <a name="grafana_api_path"></a>`grafana_api_path`

The absolute path to the API endpoint

Default value: `/api`

##### <a name="grafana_password"></a>`grafana_password`

The password for the Grafana server

##### <a name="grafana_url"></a>`grafana_url`

The URL of the Grafana server

Default value: `''`

##### <a name="grafana_user"></a>`grafana_user`

The username for the Grafana server

##### <a name="name"></a>`name`

namevar

The name of the permission.

##### <a name="organization"></a>`organization`

The name of the organization to add permission for

Default value: `Main Org.`

##### <a name="provider"></a>`provider`

The specific backend to use for this `grafana_dashboard_permission` resource. You will seldom need to specify this ---
Puppet will usually discover the appropriate provider for your platform.

##### <a name="team"></a>`team`

Team to add the permission for

##### <a name="user"></a>`user`

User to add the permission for

### <a name="grafana_datasource"></a>`grafana_datasource`

Manage datasources in Grafana

#### Properties

The following properties are available in the `grafana_datasource` type.

##### `access_mode`

Valid values: `direct`, `proxy`

Whether the datasource is accessed directly or not by the clients

Default value: `direct`

##### `basic_auth`

Valid values: ``true``, ``false``

Whether basic auth is enabled or not

Default value: `false`

##### `basic_auth_password`

The password for basic auth if enabled

Default value: `''`

##### `basic_auth_user`

The username for basic auth if enabled

Default value: `''`

##### `database`

The name of the database (optional)

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `is_default`

Valid values: ``true``, ``false``

Whether the datasource is the default one

Default value: `false`

##### `json_data`

Additional JSON data to configure the datasource (optional)

##### `password`

The password for the datasource (optional)

##### `secure_json_data`

Additional secure JSON data to configure the datasource (optional)

##### `type`

The datasource type

##### `url`

The URL/Endpoint of the datasource

##### `user`

The username for the datasource (optional)

##### `with_credentials`

Valid values: ``true``, ``false``

Whether credentials such as cookies or auth headers should be sent with cross-site requests

Default value: `false`

#### Parameters

The following parameters are available in the `grafana_datasource` type.

* [`grafana_api_path`](#grafana_api_path)
* [`grafana_password`](#grafana_password)
* [`grafana_url`](#grafana_url)
* [`grafana_user`](#grafana_user)
* [`name`](#name)
* [`organization`](#organization)
* [`provider`](#provider)

##### <a name="grafana_api_path"></a>`grafana_api_path`

The absolute path to the API endpoint

Default value: `/api`

##### <a name="grafana_password"></a>`grafana_password`

The password for the Grafana server

##### <a name="grafana_url"></a>`grafana_url`

The URL of the Grafana server

Default value: `''`

##### <a name="grafana_user"></a>`grafana_user`

The username for the Grafana server

##### <a name="name"></a>`name`

namevar

The name of the datasource.

##### <a name="organization"></a>`organization`

The organization name to create the datasource on

Default value: `1`

##### <a name="provider"></a>`provider`

The specific backend to use for this `grafana_datasource` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="grafana_folder"></a>`grafana_folder`

Manage folders in Grafana

#### Properties

The following properties are available in the `grafana_folder` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `permissions`

The permissions of the folder

#### Parameters

The following parameters are available in the `grafana_folder` type.

* [`grafana_api_path`](#grafana_api_path)
* [`grafana_password`](#grafana_password)
* [`grafana_url`](#grafana_url)
* [`grafana_user`](#grafana_user)
* [`organization`](#organization)
* [`provider`](#provider)
* [`title`](#title)
* [`uid`](#uid)

##### <a name="grafana_api_path"></a>`grafana_api_path`

The absolute path to the API endpoint

Default value: `/api`

##### <a name="grafana_password"></a>`grafana_password`

The password for the Grafana server (optional)

##### <a name="grafana_url"></a>`grafana_url`

The URL of the Grafana server

Default value: `''`

##### <a name="grafana_user"></a>`grafana_user`

The username for the Grafana server (optional)

##### <a name="organization"></a>`organization`

The organization name to create the folder on

Default value: `1`

##### <a name="provider"></a>`provider`

The specific backend to use for this `grafana_folder` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="title"></a>`title`

The title of the folder

##### <a name="uid"></a>`uid`

UID of the folder

### <a name="grafana_ldap_config"></a>`grafana_ldap_config`

Manage Grafana LDAP configuration

#### Parameters

The following parameters are available in the `grafana_ldap_config` type.

* [`backup`](#backup)
* [`group`](#group)
* [`mode`](#mode)
* [`owner`](#owner)
* [`replace`](#replace)
* [`title`](#title)
* [`validate_cmd`](#validate_cmd)

##### <a name="backup"></a>`backup`

Valid values: ``true``, ``false``, `yes`, `no`

Backup existing files before replacing them into the file-bucket

Default value: ``false``

##### <a name="group"></a>`group`

Group of the LDAP configuration file either as String or Integer (default: grafana)

Default value: `grafana`

##### <a name="mode"></a>`mode`

File-permissions mode of the LDAP configuration file as String

Default value: `0440`

##### <a name="owner"></a>`owner`

Owner of the LDAP configuration-file either as String or Integer (default: root)

Default value: `root`

##### <a name="replace"></a>`replace`

Valid values: ``true``, ``false``, `yes`, `no`

Replace existing files

Default value: ``true``

##### <a name="title"></a>`title`

Path to ldap.toml

##### <a name="validate_cmd"></a>`validate_cmd`

A command to validate the new Grafana LDAP configuration before actually replacing it

### <a name="grafana_ldap_group_mapping"></a>`grafana_ldap_group_mapping`

Map an LDAP group to a Grafana role.

#### Parameters

The following parameters are available in the `grafana_ldap_group_mapping` type.

* [`grafana_admin`](#grafana_admin)
* [`group_dn`](#group_dn)
* [`ldap_server_name`](#ldap_server_name)
* [`org_role`](#org_role)
* [`title`](#title)

##### <a name="grafana_admin"></a>`grafana_admin`

Valid values: ``true``, ``false``, `yes`, `no`

Additonal flag for Grafana > v5.3 to signal admin-role to Grafana

Default value: ``false``

##### <a name="group_dn"></a>`group_dn`

The LDAP distinguished-name of the group

##### <a name="ldap_server_name"></a>`ldap_server_name`

The LDAP server config to apply the group-mappings on

##### <a name="org_role"></a>`org_role`

Valid values: `Admin`, `Editor`, `Viewer`

The Grafana role the shall be assigned to this group

##### <a name="title"></a>`title`

A unique identifier of the resource

### <a name="grafana_ldap_server"></a>`grafana_ldap_server`

Manage Grafana LDAP servers for LDAP authentication.

#### Parameters

The following parameters are available in the `grafana_ldap_server` type.

* [`attributes`](#attributes)
* [`bind_dn`](#bind_dn)
* [`bind_password`](#bind_password)
* [`client_cert`](#client_cert)
* [`client_key`](#client_key)
* [`group_search_base_dns`](#group_search_base_dns)
* [`group_search_filter`](#group_search_filter)
* [`group_search_filter_user_attribute`](#group_search_filter_user_attribute)
* [`hosts`](#hosts)
* [`port`](#port)
* [`root_ca_cert`](#root_ca_cert)
* [`search_base_dns`](#search_base_dns)
* [`search_filter`](#search_filter)
* [`ssl_skip_verify`](#ssl_skip_verify)
* [`start_tls`](#start_tls)
* [`title`](#title)
* [`use_ssl`](#use_ssl)

##### <a name="attributes"></a>`attributes`

Mapping LDAP attributes to their Grafana user-account-properties (optional)

##### <a name="bind_dn"></a>`bind_dn`

If the LDAP server requires authentication (i.e. non-anonymous), provide the distinguished-name (dn) here (optional)

##### <a name="bind_password"></a>`bind_password`

If the LDAP server requires authentication (i.e. non-anonymous), provide the password (optional)

##### <a name="client_cert"></a>`client_cert`

If the LDAP server requires certificate-based authentication, specify the client's certificate (for TLS and SSL,
optional)

##### <a name="client_key"></a>`client_key`

If the LDAP server requires certificate-based authentication, specify the client's certificate (for TLS and SSL,
optional)

##### <a name="group_search_base_dns"></a>`group_search_base_dns`

The base-dn to be used when querying LDAP for group-accounts (optional)

##### <a name="group_search_filter"></a>`group_search_filter`

A search-filter to be used when querying LDAP for group-accounts (optional)

##### <a name="group_search_filter_user_attribute"></a>`group_search_filter_user_attribute`

The attribute to be used to locate matching user-accounts in the group (optional)

##### <a name="hosts"></a>`hosts`

The servers to perform LDAP authentication at

##### <a name="port"></a>`port`

The port to connect at the LDAP servers (389 for TLS/plaintext, 636 for SSL [ldaps], optional)

Default value: `389`

##### <a name="root_ca_cert"></a>`root_ca_cert`

The root ca-certificate to verify the LDAP server's SSL certificate against (for TLS and SSL, optional)

Default value: `/etc/ssl/certs/ca-certificates.crt`

##### <a name="search_base_dns"></a>`search_base_dns`

The one or more base-dn to be used when querying LDAP for user-accounts (optional)

Default value: `[]`

##### <a name="search_filter"></a>`search_filter`

A search-filter to be used when querying LDAP for user-accounts (optional)

##### <a name="ssl_skip_verify"></a>`ssl_skip_verify`

Valid values: ``true``, ``false``, `yes`, `no`

Set to true to disable verification of the LDAP server's SSL certificate (for TLS and SSL, optional)

Default value: ``false``

##### <a name="start_tls"></a>`start_tls`

Valid values: ``true``, ``false``, `yes`, `no`

Set to true if you want to perform LDAP via a TLS-connection (not meant to be for SSL, optional)

Default value: ``true``

##### <a name="title"></a>`title`

A unique identified for this LDAP server.

##### <a name="use_ssl"></a>`use_ssl`

Valid values: ``true``, ``false``, `yes`, `no`

Set to true if you want to perform LDAP via a SSL-connection (not meant to be for TLS, optional)

Default value: ``false``

### <a name="grafana_membership"></a>`grafana_membership`

Manage resource memberships in Grafana

#### Properties

The following properties are available in the `grafana_membership` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `role`

Valid values: `Admin`, `Editor`, `Viewer`

The role to apply to the membership (Admin, Editor, Viewer)

#### Parameters

The following parameters are available in the `grafana_membership` type.

* [`grafana_api_path`](#grafana_api_path)
* [`grafana_password`](#grafana_password)
* [`grafana_url`](#grafana_url)
* [`grafana_user`](#grafana_user)
* [`membership_type`](#membership_type)
* [`name`](#name)
* [`organization`](#organization)
* [`provider`](#provider)
* [`target_name`](#target_name)
* [`user_name`](#user_name)

##### <a name="grafana_api_path"></a>`grafana_api_path`

The absolute path to the API endpoint

Default value: `/api`

##### <a name="grafana_password"></a>`grafana_password`

The password for the Grafana server

##### <a name="grafana_url"></a>`grafana_url`

The URL of the Grafana server

Default value: `''`

##### <a name="grafana_user"></a>`grafana_user`

The username for the Grafana server

##### <a name="membership_type"></a>`membership_type`

Valid values: `organization`, `team`

The underlying type of the membership (organization, team)

##### <a name="name"></a>`name`

namevar

The name of the membership.

##### <a name="organization"></a>`organization`

The name of the organization to add membership for (team only)

Default value: `Main Org.`

##### <a name="provider"></a>`provider`

The specific backend to use for this `grafana_membership` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="target_name"></a>`target_name`

The name of the target to add membership for

##### <a name="user_name"></a>`user_name`

The name of the user to add membership for

### <a name="grafana_notification"></a>`grafana_notification`

Manage notification in Grafana

#### Properties

The following properties are available in the `grafana_notification` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `frequency`

The notification reminder frequency

##### `is_default`

Valid values: ``true``, ``false``

Whether the notification is the default one

Default value: `false`

##### `send_reminder`

Valid values: ``true``, ``false``

Whether automatic message resending is enabled or not

Default value: `false`

##### `settings`

Additional JSON data to configure the notification

##### `type`

The notification type

#### Parameters

The following parameters are available in the `grafana_notification` type.

* [`grafana_api_path`](#grafana_api_path)
* [`grafana_password`](#grafana_password)
* [`grafana_url`](#grafana_url)
* [`grafana_user`](#grafana_user)
* [`name`](#name)
* [`provider`](#provider)

##### <a name="grafana_api_path"></a>`grafana_api_path`

The absolute path to the API endpoint

Default value: `/api`

##### <a name="grafana_password"></a>`grafana_password`

The password for the Grafana server

##### <a name="grafana_url"></a>`grafana_url`

The URL of the Grafana server

Default value: `''`

##### <a name="grafana_user"></a>`grafana_user`

The username for the Grafana server

##### <a name="name"></a>`name`

namevar

The name of the notification.

##### <a name="provider"></a>`provider`

The specific backend to use for this `grafana_notification` resource. You will seldom need to specify this --- Puppet
will usually discover the appropriate provider for your platform.

### <a name="grafana_organization"></a>`grafana_organization`

Manage organizations in Grafana

#### Properties

The following properties are available in the `grafana_organization` type.

##### `address`

Additional JSON data to configure the organization address (optional)

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `id`

The ID of the organization

#### Parameters

The following parameters are available in the `grafana_organization` type.

* [`grafana_api_path`](#grafana_api_path)
* [`grafana_password`](#grafana_password)
* [`grafana_url`](#grafana_url)
* [`grafana_user`](#grafana_user)
* [`name`](#name)
* [`provider`](#provider)

##### <a name="grafana_api_path"></a>`grafana_api_path`

The absolute path to the API endpoint

Default value: `/api`

##### <a name="grafana_password"></a>`grafana_password`

The password for the Grafana server

##### <a name="grafana_url"></a>`grafana_url`

The URL of the Grafana server

Default value: `''`

##### <a name="grafana_user"></a>`grafana_user`

The username for the Grafana server

##### <a name="name"></a>`name`

namevar

The name of the organization.

##### <a name="provider"></a>`provider`

The specific backend to use for this `grafana_organization` resource. You will seldom need to specify this --- Puppet
will usually discover the appropriate provider for your platform.

### <a name="grafana_plugin"></a>`grafana_plugin`

manages grafana plugins

#### Examples

##### Install a grafana plugin

```puppet
grafana_plugin { 'grafana-simple-json-datasource': }
```

##### Install a grafana plugin from different repo

```puppet
grafana_plugin { 'grafana-simple-json-datasource':
  ensure => 'present',
  repo   => 'https://nexus.company.com/grafana/plugins',
}
```

##### Install a grafana plugin from a plugin url

```puppet
grafana_plugin { 'grafana-example-custom-plugin':
  ensure     => 'present',
  plugin_url => 'https://github.com/example/example-custom-plugin/zipball/v1.0.0'
}
```

##### Uninstall a grafana plugin

```puppet
grafana_plugin { 'grafana-simple-json-datasource':
  ensure => 'absent',
}
```

##### Show resources

```puppet
$ puppet resource grafana_plugin
```

#### Properties

The following properties are available in the `grafana_plugin` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `grafana_plugin` type.

* [`name`](#name)
* [`plugin_url`](#plugin_url)
* [`provider`](#provider)
* [`repo`](#repo)

##### <a name="name"></a>`name`

Valid values: `%r{^\S+$}`

namevar

The name of the plugin to enable

##### <a name="plugin_url"></a>`plugin_url`

Full url to the plugin zip file

##### <a name="provider"></a>`provider`

The specific backend to use for this `grafana_plugin` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="repo"></a>`repo`

The URL of an internal plugin server

### <a name="grafana_team"></a>`grafana_team`

Manage teams in Grafana

#### Properties

The following properties are available in the `grafana_team` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `home_dashboard`

The id or name of the home dashboard

Default value: `Default`

##### `home_dashboard_folder`

The UID or name of the home dashboard folder

##### `theme`

The theme to use for the team

##### `timezone`

The timezone to use for the team

#### Parameters

The following parameters are available in the `grafana_team` type.

* [`email`](#email)
* [`grafana_api_path`](#grafana_api_path)
* [`grafana_password`](#grafana_password)
* [`grafana_url`](#grafana_url)
* [`grafana_user`](#grafana_user)
* [`name`](#name)
* [`organization`](#organization)
* [`provider`](#provider)

##### <a name="email"></a>`email`

The email for the team

Default value: `''`

##### <a name="grafana_api_path"></a>`grafana_api_path`

The absolute path to the API endpoint

Default value: `/api`

##### <a name="grafana_password"></a>`grafana_password`

The password for the Grafana server

##### <a name="grafana_url"></a>`grafana_url`

The URL of the Grafana server

Default value: `''`

##### <a name="grafana_user"></a>`grafana_user`

The username for the Grafana server

##### <a name="name"></a>`name`

namevar

The name of the team

##### <a name="organization"></a>`organization`

The organization the team belongs to

Default value: `Main Org.`

##### <a name="provider"></a>`provider`

The specific backend to use for this `grafana_team` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="grafana_user"></a>`grafana_user`

Manage users in Grafana

#### Properties

The following properties are available in the `grafana_user` type.

##### `email`

The email for the user

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `is_admin`

Valid values: ``true``, ``false``

Whether the user is a grafana admin

Default value: `false`

##### `password`

The password for the user

##### `theme`

The theme for the user

#### Parameters

The following parameters are available in the `grafana_user` type.

* [`full_name`](#full_name)
* [`grafana_api_path`](#grafana_api_path)
* [`grafana_password`](#grafana_password)
* [`grafana_url`](#grafana_url)
* [`grafana_user`](#grafana_user)
* [`name`](#name)
* [`provider`](#provider)

##### <a name="full_name"></a>`full_name`

The full name of the user.

##### <a name="grafana_api_path"></a>`grafana_api_path`

The absolute path to the API endpoint

Default value: `/api`

##### <a name="grafana_password"></a>`grafana_password`

The password for the Grafana server

##### <a name="grafana_url"></a>`grafana_url`

The URL of the Grafana server

Default value: `''`

##### <a name="grafana_user"></a>`grafana_user`

The username for the Grafana server

##### <a name="name"></a>`name`

namevar

The username of the user.

##### <a name="provider"></a>`provider`

The specific backend to use for this `grafana_user` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

## Functions

### <a name="grafanadeep_find_and_remove"></a>`grafana::deep_find_and_remove`

Type: Ruby 4.x API

== Function: deep_find_and_remove

This function takes a hash as input, along with a string
(key). Additionally, the optional removekey (defaults to
'puppetsource') is a parameter.

The purpose of this function is to extract the 'options' subhash
from the array of hashes given to provision dashboards. This options
subhash may contain a path and source which puppet will use for
provisioning: creating the path and applying the files from the
source.

Additionally, if the key 'puppetsource' exists in the sub-hash, it
will be deleted from the structure. Thus the output of this function
may be used in yaml format for grafana's provisioning
configuration file for dashboards.

#### `grafana::deep_find_and_remove(String $key, Hash $object, Optional[String] $removekey)`

== Function: deep_find_and_remove

This function takes a hash as input, along with a string
(key). Additionally, the optional removekey (defaults to
'puppetsource') is a parameter.

The purpose of this function is to extract the 'options' subhash
from the array of hashes given to provision dashboards. This options
subhash may contain a path and source which puppet will use for
provisioning: creating the path and applying the files from the
source.

Additionally, if the key 'puppetsource' exists in the sub-hash, it
will be deleted from the structure. Thus the output of this function
may be used in yaml format for grafana's provisioning
configuration file for dashboards.

Returns: `Array`

##### `key`

Data type: `String`



##### `object`

Data type: `Hash`



##### `removekey`

Data type: `Optional[String]`



### <a name="grafanaget_sub_paths"></a>`grafana::get_sub_paths`

Type: Ruby 4.x API

== Function get_sub_paths

This function receives an input path as an input parameter, and
returns an array of the subpaths in the input, excluding the input
path itself. The function will attempt to ignore any extra slashes
in the path given.

This function will only work on UNIX paths with forward slashes (/).

Examples:
input = '/var/lib/grafana/dashboards'
output = [ '/var', '/var/lib', '/var/lib/grafana'/ ]

input = '/opt'
output = []

input = '/first/second/'
output = [ '/first' ]

#### `grafana::get_sub_paths(String $inputpath)`

== Function get_sub_paths

This function receives an input path as an input parameter, and
returns an array of the subpaths in the input, excluding the input
path itself. The function will attempt to ignore any extra slashes
in the path given.

This function will only work on UNIX paths with forward slashes (/).

Examples:
input = '/var/lib/grafana/dashboards'
output = [ '/var', '/var/lib', '/var/lib/grafana'/ ]

input = '/opt'
output = []

input = '/first/second/'
output = [ '/first' ]

Returns: `Array`

##### `inputpath`

Data type: `String`



## Tasks

### <a name="change_grafana_admin_password"></a>`change_grafana_admin_password`

Change the Grafana admin user's password

**Supports noop?** false

#### Parameters

##### `old_password`

Data type: `Optional[String[1]]`

The old admin password

##### `new_password`

Data type: `Optional[String[1]]`

The new admin password

##### `uri`

Data type: `Enum['http','https']`

http or https

##### `port`

Data type: `Integer`

The port Grafana is running on

