class postgresql_veil_controller {

  class { 'postgresql::globals': }
  -> class { 'postgresql::client': }
  -> class { 'postgresql::server':
    port => 5433,
  }
  -> file { "/var/log/postgresql":
    ensure  => directory,
    owner => 'postgres',
    group => 'postgres',
    mode => '0750',
   }
  -> file { "/var/log/postgresql/pg_log":
    ensure  => directory,
    owner => 'postgres',
    group => 'postgres',
    mode => '0750',
   }
   -> postgresql::server::role { 'veil':
     createdb => true,
     password_hash => postgresql_password('veil', 'bazalt'),
  }
  -> postgresql::server::db { 'veildb':
    user     => 'veil',
    owner    => 'veil',
    password => postgresql_password('veil', 'bazalt'),
  } ->
  postgresql::server::database_grant { 'veil':
    privilege => 'ALL',
    db        => 'veildb',
    role      => 'veil',
  }
  -> postgresql::server::pg_hba_rule { 'allow backup script':
     order       => '001',
     description => "Backup base_backup script",
     type        => 'host',
     database    => 'replication',
     user        => 'postgres',
     address     => '127.0.0.1/32',
     auth_method => 'trust',
  } -> postgresql::server::pg_hba_rule { 'slave replication':
    order       => '002',
    description => 'slave replication',
    type        => 'host',
    database    => 'replication',
    user        => 'all',
    address     => '0.0.0.0/0',
    auth_method => 'trust',
  } -> postgresql::server::pg_hba_rule { 'allow veil user via 0.0.0.0':
    order       => '005',
    description => "For veil user",
    type        => 'host',
    database    => 'all',
    user        => 'veil',
    address     => '0.0.0.0/0',
#    auth_method => 'password',
    auth_method => 'md5',
  } -> postgresql::server::pg_hba_rule { 'local replication as postgres user':
    order       => '002',
    description => 'local replication as postgres user',
    type        => 'local',
    database    => 'replication',
    user        => 'postgres',
    auth_method => 'peer',
  } -> postgresql::server::pg_ident_rule { 'Map root':
  map_name          => 'postgres',
  system_username   => 'root',
  database_username => 'postgres',
  } -> postgresql::server::pg_ident_rule { 'Map postgres':
  map_name          => 'postgres',
  system_username   => 'postgres',
  database_username => 'postgres',
  }

# $listen_addresses           = undef
#$port = 5432

  # settings for ISO boot. On production env other
  #postgresql::server::config_entry { 'port': value                 => '6432' }
  #postgresql::server::config_entry { 'listen_addresses': value                 => '*' }
  postgresql::server::config_entry { 'timezone': value                 => 'UTC' }
  postgresql::server::config_entry { 'log_timezone': value                 => 'UTC' }
  postgresql::server::config_entry { 'datestyle': value                 => 'iso, mdy' }

  postgresql::server::config_entry { 'max_connections': value                 => 512 }
  postgresql::server::config_entry { 'shared_buffers': value                  => '128MB' }
#  postgresql::server::config_entry { 'temp_buffers': value                    => '64MB' }
#  postgresql::server::config_entry { 'work_mem': value                        => '64MB' }
#  postgresql::server::config_entry { 'maintenance_work_mem': value            => '128MB' }
  postgresql::server::config_entry { 'bgwriter_delay': value                  => '500ms' }
  postgresql::server::config_entry { 'effective_io_concurrency': value        => '2' }
  postgresql::server::config_entry { 'max_worker_processes': value            => '8' }
  postgresql::server::config_entry { 'synchronous_commit': value              => 'off' }
  postgresql::server::config_entry { 'checkpoint_completion_target': value    => '0.9' }

  # more config: WAL related, needed for streaming replication in future
  postgresql::server::config_entry { 'wal_level': value                       => 'hot_standby' }
  postgresql::server::config_entry { 'wal_compression': value                 => 'on' }
  postgresql::server::config_entry { 'commit_delay': value                    => '10000' }
  postgresql::server::config_entry { 'max_wal_size': value                    => '3GB' }

  postgresql::server::config_entry { 'max_wal_senders': value                 => '5' }
  postgresql::server::config_entry { 'max_replication_slots': value           => '5' }
#  postgresql::server::config_entry { 'wal_keep_segments': value               => '128' }
  postgresql::server::config_entry { 'hot_standby': value                     => 'on' }

  postgresql::server::config_entry { 'log_filename': value => "postgresql-%Y-%m-%d-%H.log" }
  #postgresql::server::config_entry { 'log_timezone': value => "W-SU" }
  postgresql::server::config_entry { 'log_rotation_age': value => "1h" }
  postgresql::server::config_entry { 'log_destination': value => "csvlog" }
  postgresql::server::config_entry { 'log_truncate_on_rotation': value => "on" }
  postgresql::server::config_entry { 'log_directory': value => "/var/log/postgresql/pg_log" }
  postgresql::server::config_entry { 'track_counts': value => "on" }

  package {['postgresql-common', 'postgresql-client-common']:
    ensure   => latest,
  }
}
