# Class: sysctl
# Accept key: value hash with sysctl params. Apply them in runtime and save to sysctl.conf
# By default perform lookup lookup for sysctl::params key.
# == Example:
# = manifest:
# include sysctl
# = hiera:
# sysctl::params:
#  'fs.file-max': '512000'
#  'net.core.somaxconn': '4096'
class sysctl (
    $params = lookup('sysctl::params', {}),
){

case $operatingsystem {
    freebsd: {
      $apply_cmd="/sbin/sysctl -i -f /etc/sysctl.conf"
      }
    default: {
      $apply_cmd="/sbin/sysctl -p"
      }
}
    exec { 'sysctl_apply' :
        command     => $apply_cmd,
        refreshonly => true,
        returns     => ['0', '255'],
        logoutput   => 'on_failure',
    }

    $final_params = add_sub_key($params, 'value') # convert {a: b} to {a: {'value': b}}
    create_resources('sysctl::conf', $final_params)

}
