class veil_log {

   # for gem
   ensure_resource('package', 'ruby', {'ensure' => 'present'})
   ensure_resource('package', 'ruby-dev', {'ensure' => 'present'})
   ensure_resource('package', 'gcc', {'ensure' => 'present'})
   ensure_resource('package', 'make', {'ensure' => 'present'})

   include '::fluentd'

   ::fluentd::plugin { 'faraday':
     type   => 'file',
     source => "puppet:///modules/${module_name}/faraday-0.15.4.gem",
   }

   exec { 'grafana_loki_install':
    command => "td-agent-gem install -N --conservative --minimal-deps --no-document --force --local /etc/puppetveil/code/environments/production/modules/veil_log/files/fluent-plugin-grafana-loki-1.2.20.gem",
    unless  => "td-agent-gem list --local | grep fluent-plugin-grafana-loki | grep 1.2.20",
  }

   ::fluentd::plugin { 'fluent-plugin-grafana-loki':
     type   => 'file',
     source => "puppet:///modules/${module_name}/fluent-plugin-grafana-loki-1.2.20.gem",
   }

   fluentd::source { 'collector':
     priority => 10,
     config   => {
       'bind' => '::',
       'type' => 'forward',
     }
   }

   fluentd::match { 'rewrite_local_tag':
     priority => 50,
     pattern => 'local.**',
     config   => {
       '@type' => 'rewrite_tag_filter',
       'remove_tag_prefix' => 'local',
        rule => {
          key => 'host',
          pattern => '.+',
          tag => '${tag}'
        }
     }
   }

   fluentd::match { 'rewrite_remote_tag':
     priority => 50,
     pattern => 'remote.**',
     config   => {
       '@type' => 'rewrite_tag_filter',
       'remove_tag_prefix' => 'remote',
        rule => {
          key => 'host',
          pattern => '.+',
          tag => '${tag}'
        }
     }
   }

    fluentd::match { 'system.syslog_loki':
     priority => 55,
     pattern => 'system.syslog',
     config  => {
       '@type' => 'loki',
       'url' => 'http://localhost:3100',
       'extra_labels' => '{"name":"system.syslog"}',
       'buffer' => {"flush_interval" => "10s", "flush_at_shutdown" => "true"},
       'buffer_chunk_limit' => '1m',
     },
   }

    fluentd::match { 'veil.node_loki':
     priority => 55,
     pattern => 'veil.node',
     config  => {
       '@type' => 'loki',
       'url' => 'http://localhost:3100',
       'extra_labels' => '{"name":"veil.node"}',
       'buffer' => {"flush_interval" => "10s", "flush_at_shutdown" => "true"},
       'buffer_chunk_limit' => '1m',
       'line_format' => 'json'
     },
   }

    fluentd::match { 'veil.controller_loki':
     priority => 55,
     pattern => 'veil.controller',
     config  => {
       '@type' => 'loki',
       'url' => 'http://localhost:3100',
       'extra_labels' => '{"name":"veil.controller"}',
       'buffer' => {"flush_interval" => "10s", "flush_at_shutdown" => "true"},
       'buffer_chunk_limit' => '1m',
       'line_format' => 'json'
     },
   }

    fluentd::match { 'veil.cli_loki':
     priority => 55,
     pattern => 'veil.cli',
     config  => {
       '@type' => 'loki',
       'url' => 'http://localhost:3100',
       'extra_labels' => '{"name":"veil.cli"}',
       'buffer' => {"flush_interval" => "10s", "flush_at_shutdown" => "true"},
       'buffer_chunk_limit' => '1m',
       'line_format' => 'json'
     },
   }

    fluentd::match { 'fluent_loki':
     priority => 55,
     pattern => 'fluent.*',
     config  => {
       '@type' => 'loki',
       'url' => 'http://localhost:3100',
       'label' => {"first" => "@FLUENT_LOG"},
       'extra_labels' => '{"name":"fluentd"}',
       'buffer' => {"flush_interval" => "10s", "flush_at_shutdown" => "true"},
       'buffer_chunk_limit' => '1m',
     },
   }
}
