#!/usr/bin/env python3
# coding=utf-8

import argparse
import json
import requests


def get_token(url, user, password):
    r = requests.post(f'{url}/auth/',
                      params={},
                      data=json.dumps({'username': user, 'password': password}),
                      headers={'content-type': 'application/json'},
                      timeout=10)
    r.raise_for_status()
    return r.json()


def get_args():
    parser = argparse.ArgumentParser(description='get token')
    parser.add_argument('--url', type=str, required=True, help='API url, e.g http://127.0.0.1')
    parser.add_argument('-u', '--user', required=True, type=str, help='API user')
    parser.add_argument('-p', '--password', required=True, type=str, help='API password')
    return parser.parse_args()


def main(args):
    auth_json = get_token(args.url, args.user, args.password)
    assert len(auth_json) > 1, "auth returned more then 2 token: {0}".format(auth_json)

    token = auth_json['token']
    assert len(token) > 0, "token not found"

    print(token)


if __name__ == '__main__':
    main(get_args())
