#!/usr/bin/python3
"""
Получаем 4 числовых параметра,-- потоки для veil.slice, относительных попугаев (в диапазоне 1..1000) для system, user,
 machine slices соответственно. Если параметров нет, veil.slice получает 2 потока и прочие слайсы делят остальные
 потоки поровну. Попугаи имеют только относительный смысл, не обязательно составлять 100% в сумме.
 Если ядер 2 или 1, veil.slice получает их все, если будет надо.
"""
import sys
from multiprocessing import cpu_count
import subprocess

if len(sys.argv) != 5:
    print("Parameters not set! Used defaults: 2 threads for veil.slice, 33% for system,"
          " user and machine slices")
    args = [2, 33, 33, 33]
else:
    try:
        args = [int(x) for x in sys.argv[1:] if int(x) > 0]
        print(f"Parameters used: {args[0]} cores for veil, {args[1]} for system, {args[2]} for user, "
              f"{args[3]} for machine")
    except Exception:
        print("Wrong parameters! Used defaults: 2 threads for veil.slice, 33% for system, "
              "user and machine slices")
        args = [2, 33, 33, 33]

cpus = cpu_count()
if cpus < 3 or cpus - args[0] <= 0:
    print(f'Not enough CPUs found: {cpus}. {args[0]} CPUs required. Priority to VeiL services is given')
    values = dict(veil=1000, system=100, user=100, machine=100)
else:
    cpus_no_veil = cpus - args[0]  # отдаём вейлу сколько задано в конфиге потоков
    total_score = sum(args[1:])
    score_per_core = total_score / cpus_no_veil
    values = dict(veil=score_per_core * 2,
                  system=args[1],
                  user=args[2],
                  machine=args[3])

    for name, v in values.items():
        subprocess.Popen(["systemctl", "set-property", f"{name}.slice", f"CPUWeight={int(v * 10)}"], shell=False)
