# configure environment to install controller from .deb and dev repo
class veil_node::dirs {
  $veil_global_group = lookup('veil_global_group')
  $veil_node_user = lookup('veil_node_user')

  # fix bug when zfs modules can't build on current linux kernel
  # $kernel_version_array = ['5.9.0-2', '5.10.0-8', '5.10.0-15']

  exec { 'remove_headers_5.9.0-2':
    command => "rm -rf /lib/modules/5.9.0-2-amd64/build/",
    onlyif  => "test ! -f /lib/modules/5.9.0-2-amd64/build/Makefile",
    path    =>  ["/usr/bin","/usr/sbin", "/bin"],
  } ->

  exec { 'symlink_headers_5.9.0-2':
    command => "ln -sT /usr/src/linux-headers-5.9.0-2-amd64 /lib/modules/5.9.0-2-amd64/build",
    onlyif  => "test -d /usr/src/linux-headers-5.9.0-2-amd64",
    creates => "/lib/modules/5.9.0-2-amd64/build",
    path    =>  ["/usr/bin","/usr/sbin", "/bin"],
  } ->

  exec { 'symlink_headers_5.9.0-2_common':
    command => "ln -s /usr/src/linux-headers-5.9.0-2-common/include/linux /lib/modules/5.9.0-2-amd64/build/include/linux",
    onlyif  => "test -d /usr/src/linux-headers-5.9.0-2-common/include/linux && test -d /lib/modules/5.9.0-2-amd64/build/include",
    creates => "/lib/modules/5.9.0-2-amd64/build/include/linux",
    path    =>  ["/usr/bin","/usr/sbin", "/bin"],
  }


  exec { 'remove_headers_5.10.0-8':
    command => "rm -rf /lib/modules/5.10.0-8-amd64/build/",
    onlyif  => "test ! -f /lib/modules/5.10.0-8-amd64/build/Makefile",
    path    =>  ["/usr/bin","/usr/sbin", "/bin"],
  } ->

  exec { 'symlink_headers_5.10.0-8':
    command => "ln -sT /usr/src/linux-headers-5.10.0-8-amd64 /lib/modules/5.10.0-8-amd64/build",
    onlyif  => "test -d /usr/src/linux-headers-5.10.0-8-amd64",
    creates => "/lib/modules/5.10.0-8-amd64/build",
    path    =>  ["/usr/bin","/usr/sbin", "/bin"],
  } ->

  exec { 'symlink_headers_5.10.0-8_common':
    command => "ln -s /usr/src/linux-headers-5.10.0-8-common/include/linux /lib/modules/5.10.0-8-amd64/build/include/linux",
    onlyif  => "test -d /usr/src/linux-headers-5.10.0-8-common/include/linux",
    creates => "/lib/modules/5.10.0-8-amd64/build/include/linux",
    path    =>  ["/usr/bin","/usr/sbin", "/bin"],
  }


  exec { 'remove_headers_5.10.0-15':
    command => "rm -rf /lib/modules/5.10.0-15-amd64/build/",
    onlyif  => "test ! -f /lib/modules/5.10.0-15-amd64/build/Makefile",
    path    =>  ["/usr/bin","/usr/sbin", "/bin"],
  } ->

  exec { 'symlink_headers_5.10.0-15':
    command => "ln -sT /usr/src/linux-headers-5.10.0-15-amd64 /lib/modules/5.10.0-15-amd64/build",
    onlyif  => "test -d /usr/src/linux-headers-5.10.0-15-amd64",
    creates => "/lib/modules/5.10.0-15-amd64/build",
    path    =>  ["/usr/bin","/usr/sbin", "/bin"],
  } ->

  exec { 'symlink_headers_5.10.0-15_common':
    command => "ln -s /usr/src/linux-headers-5.10.0-15-common/include/linux /lib/modules/5.10.0-15-amd64/build/include/linux",
    onlyif  => "test -d /usr/src/linux-headers-5.10.0-15-common/include/linux",
    creates => "/lib/modules/5.10.0-15-amd64/build/include/linux",
    path    =>  ["/usr/bin","/usr/sbin", "/bin"],
  }

  #-------------------------------------------


  $file_defaults = {
    'ensure' => directory,
  }

  $storages_dir_hier = {
    '/storages'                => {
       owner => $veil_node_user,
       group => $veil_node_user,
       mode => '0775',
    },
    '/storages/local'          => {
       owner => $veil_node_user,
       group => $veil_node_user,
       mode => '0775',
    },
    '/storages/local/default'  => {
       owner => $veil_node_user,
       group => $veil_node_user,
       mode => '0775',
    },
    '/storages/ocfs2'          => {
      owner => $veil_node_user,
      group => $veil_node_user,
      mode  => '0775',
    },
    '/storages/gfs2'           => {
      owner => $veil_node_user,
      group => $veil_node_user,
      mode  => '0775',
    },
    '/storages/nfs'            => {
      owner => $veil_node_user,
      group => $veil_node_user,
      mode  => '0775',
    },
    '/storages/glusterfs'      => {
      owner => $veil_node_user,
      group => $veil_node_user,
      mode  => '0775',
    },
    '/storages/cifs'           => {
      owner => $veil_node_user,
      group => $veil_node_user,
      mode  => '0775',
    },
    '/storages/gluster'        => {
      owner => $veil_node_user,
      group => $veil_node_user,
      mode  => '0775',
    },
    '/storages/minio'          => {
      owner => $veil_node_user,
      group => $veil_node_user,
      mode  => '0775',
    },
    '/usr/libexec/glusterfs'   => {
      owner => $veil_node_user,
      group => $veil_node_user,
      mode  => '0775',
    }
  }

  create_resources(file, $storages_dir_hier, $file_defaults)
  
  file { "/var/lib/ecp-veil/.users":
    mode => '0775',
    owner => $veil_node_user,
    group => $veil_node_user,
    ensure => directory,
  } ->
  file { "/var/lib/ecp-veil/.users/veil-node":
    mode => '0700',
    owner => $veil_node_user,
    group => $veil_node_user,
    ensure => directory,
  } ->
  file { "/var/lib/ecp-veil/.users/veil-node/.ssh":
    mode => '0700',
    owner => $veil_node_user,
    group => $veil_node_user,
    ensure => directory,
  } ->
  file { "/var/lib/ecp-veil/.users/veil-node/.ssh/config":
    mode => '0600',
    owner => $veil_node_user,
    group => $veil_node_user,
    ensure  => file,
  } ->
  file { "/var/lib/ecp-veil/.users/veil-node/.ssh/authorized_keys":
    mode => '0600',
    owner => $veil_node_user,
    group => $veil_node_user,
    ensure  => file,
  } ->
  file { "/var/lib/ecp-veil/node":
    mode => '0775',
    owner => $veil_node_user,
    group => $veil_global_group,
    ensure => directory,
  } ->
    file { "/var/lib/ecp-veil/node/local_domains":
    mode => '0775',
    owner => $veil_node_user,
    group => $veil_global_group,
    ensure => directory,
  } ->
  file { "/var/lib/ecp-veil/node/bin":
    mode => '0775',
    owner => $veil_node_user,
    group => $veil_node_user,
    ensure => directory,
    recurse => true,
    recurselimit => 1,
  } ->
  file { "/var/lib/ecp-veil/node/ppt":
    mode => '0700',
    owner => $veil_node_user,
    group => $veil_node_user,
    ensure => directory,
  } ->
  file { "/var/lib/ecp-veil/node/other/auth.py":
    source  => [
            "puppet:///modules/${module_name}/auth.py",
    ],
    mode => '0550',
  } ->
  file { "/var/log/veil/node/":
    mode => '0775',
    owner => $veil_node_user,
    group => $veil_global_group,
    ensure => directory,
    recurse => true,
    recurselimit => 1,
  } ->
  file { "/var/log/veil/node/journal":
    ensure => directory,
    owner => $veil_node_user,
    group => $veil_global_group,
    mode => '0770',
  } ->
  file { "/var/log/veil/node/net_backups":
    ensure => directory,
    owner => $veil_node_user,
    group => $veil_global_group,
    mode => '0770',
  } ->
  file { "/var/log/veil/node/fence_ipmilan.log":
    mode => '0666',
    owner => $veil_node_user,
    group => $veil_global_group,
    ensure  => file,
  } ->
  file { "/var/log/veil/node/detect-device":
    ensure => directory,
    owner => $veil_node_user,
    group => $veil_global_group,
    mode => '0770',
  } ->
  exec { "veil-generate-events":
    command => "/usr/local/sbin/veil-generate-events || true",
  } ->
  file { "/var/log/veil/cli/":
    mode => '0777',
    owner => $veil_node_user,
    group => $veil_global_group,
    ensure => directory,
    recurse => true,
    recurselimit => 1,
  } ->
  file { "/var/log/veil/cli/cli.log":
    mode => '0666',
    owner => $veil_node_user,
    group => $veil_global_group,
    ensure  => file,
  } ->
  file { "/var/log/crash/":
    mode => '0666',
    owner => $veil_node_user,
    group => $veil_global_group,
    ensure => directory,
    recurse => true,
    recurselimit => 1,
  } ->
  file { "/var/lib/consul":
    mode   => '0775',
    owner  => consul,
    group  => consul,
    ensure => directory,
  } ->
    file { "/var/log/consul":
    mode   => '0777',
    owner  => consul,
    group  => consul,
    ensure => directory,
  } ->
    file { "/etc/minio":
    mode   => '0775',
    owner  => $veil_node_user,
    group  =>  $veil_global_group,
    ensure => directory,
    recurse => true,
    recurselimit => 1,
  } ->
  file { "/sys/kernel/mm/ksm":
    mode   => '0664',
    owner => $veil_node_user,
    group => $veil_global_group,
    ensure => directory,
    recurse => true,
  } ->
  file { "/etc/mdev-instances.d":
    owner => root,
    group => root,
    ensure => directory,
  } ->
  file { "/var/lib/ecp-veil/node/bin/bad_scsi_kill":
    source => [ "puppet:///modules/${module_name}/bad_scsi_kill" ],
    owner  => root,
    group  => root,
    mode   => '0755',
  } ->
  file { "/var/lib/ecp-veil/node/local_data":
    mode   => '0770',
    owner => $veil_node_user,
    group => $veil_global_group,
    ensure => directory,
    recurse => true,
  } ->
  file { "/usr/share/seabios/vgabios-ramfb.bin":
    source  => [ "puppet:///modules/${module_name}/vgabios-ramfb.bin" ],
    owner => root,
    group => root,
    mode => '0644',
  } ->
  file { "/etc/ulogd.conf":
    source  => [ "puppet:///modules/${module_name}/ulogd.conf" ],
    owner => root,
    group => root,
    mode => '0660',
  } ->
  file { "/var/lib/glusterd/groups/veil":
    source => [ "puppet:///modules/${module_name}/veil_gluster" ],
    mode => '0644',
    owner => root,
    group => root,
    ensure  => file,
  }

  file { "/var/lib/glusterd/groups/dispersed-virt":
    source => [ "puppet:///modules/${module_name}/dispersed-gluster" ],
    mode => '0644',
    owner => root,
    group => root,
    ensure  => file,
  }

  file { "/var/lib/ecp-veil/node/bin/networks":
    mode   => '0775',
    owner => $veil_node_user,
    group => $veil_global_group,
    ensure => directory,
  } ->
  file { "/var/lib/ecp-veil/node/bin/networks/port-mirrors.json":
    mode => '0644',
    owner => root,
    group => root,
    ensure  => file,
    replace => 'no',
    content => "[]\n",
  } ->
  file { "/var/lib/ecp-veil/node/bin/networks/sriov-state.json":
    mode => '0644',
    owner => root,
    group => root,
    ensure  => file,
    replace => 'no',
    content => "[]\n",
  } ->
  file { "/var/lib/ecp-veil/node/bin/networks/traffic-block.json":
    mode => '0644',
    owner => root,
    group => root,
    ensure  => file,
    replace => 'no',
    content => "[]\n",
  } ->
  file { "/var/lib/ecp-veil/node/bin/networks/vmachines-qos-policy-marking.json":
    mode => '0644',
    owner => root,
    group => root,
    ensure  => file,
    replace => 'no',
    content => "[]\n",
 } ->
  file { '/var/lib/ecp-veil/node/bazalt/settings_system.py':
    source => [ "puppet:///modules/${module_name}/settings_system.py" ],
    ensure  => 'present',
    replace => 'no', # this is the important property
    mode    => '0640',
    owner => $veil_node_user,
    group => $veil_global_group,
  }
}