# configure environment to install controller from .deb and dev repo
class veil_node::fluentd_config
{
  $severity_levels = ['emergency', 'alert', 'critical', 'error', 'warning', 'notice', 'info', 'debug']

  if $controller_ip == "127.0.0.1" {
    $logger=[ { 'host' => '127.0.0.1', 'port' => '24224'} ]
  } else {
    $logger=[ { 'host' => $controller_ip, 'port' => '24224'} ]
  }

  if $is_controller_media == '0' {
    $tag = 'remote'
  } else {
    $tag = 'local'
  }

  fluentd::match { 'forward_system':
    priority => 90,
    pattern => '**',
    config   => {
      '@type'    => 'forward',
      'server' => $logger,
    }
  }

  $severity_levels.each |String $level| {
    # собираем логи по уровням важности
    fluentd::source { "syslog_${level}":
      config => {
        '@type' => 'tail',
        format => 'syslog',
        tag => "${level}.${tag}.system.syslog",
        encoding => 'UTF-8',
        path => "/var/log/${level}.system.syslog",
        pos_file => "/var/log/td-agent/td-agent.${level}.syslog.pos",
      },
      notify => Class['fluentd::service']
    }

    fluentd::source { "syslog_${level}_1":
      config => {
        '@type' => 'tail',
        format => 'syslog',
        tag => "${level}.${tag}.system.syslog",
        encoding => 'UTF-8',
        path => "/var/log/${level}.system.syslog.1",
        pos_file => "/var/log/td-agent/td-agent.${level}.syslog_1.pos",
      },
      notify => Class['fluentd::service']
    }

    # добавляем поле указывающее уровень важности
    fluentd::filter { "transform_${level}_syslog":
      priority => 20,
      pattern => "${level}.**",
      config => {
        '@type' => 'record_transformer',
        record => {
          levelname => upcase($level)
        }
      },
      notify => Class['fluentd::service']
    }

    # чистим теги
    fluentd::match { "rewrite_${level}_tag":
      priority => 25,
      pattern => "${level}.**",
      config   => {
        '@type' => 'rewrite_tag_filter',
        'remove_tag_prefix' => $level,
        rule => {
          key => 'host',
          pattern => '.+',
          tag => '${tag}'
        }
      }
    }
  }

  fluentd::source { 'syslog_dpkg':
    config => {
      '@type' => 'tail',
      format => '/(?<time>^[^ ]+ [^ ]+) (?<message>.*)/',
      time_format => '%Y-%m-%d %H:%M:%S',
      tag => sprintf('%s.dpkg', $tag),
      path => '/var/log/dpkg.log',
      pos_file => '/var/log/td-agent/td-agent.dpkg.pos',
    },
    notify => Class['fluentd::service']
  }

  fluentd::source { 'veil_node_log':
    config => {
      '@type' => 'tail',
      format => 'json',
      tag => sprintf('%s.veil.node', $tag),
      path => '/var/log/veil/node/node.log',
      pos_file => '/var/log/td-agent/veil_node.log.pos',
    },
    notify => Class['fluentd::service']
  }

  fluentd::source { 'veil_cli_log':
    config => {
      '@type' => 'tail',
      format => 'json',
      tag => sprintf('%s.veil.cli', $tag),
      path => '/var/log/veil/cli/cli.log',
      pos_file => '/var/log/td-agent/veil_cli.log.pos',
    },
    notify => Class['fluentd::service']
  }

  # добавляем поле ident для dpkg логов
  fluentd::filter { 'transform_dpkg':
    priority => 20,
    pattern => sprintf('%s.dpkg', $tag),
    config => {
      '@type' => 'record_transformer',
      record => {
        ident => 'dpkg'
      }
    },
    notify => Class['fluentd::service']
  }

  # Добавляем настройку фильтра добавляющего тег и host/hostname для логов
  fluentd::filter { 'transform_add_host':
    priority => 30,
    pattern => sprintf('%s.**', $tag),
    config => {
      '@type' => 'record_transformer',
      enable_ruby => '',
      record => {
        hostname => '"#{Socket.gethostname}"',
        host => '"#{Socket.gethostname; Socket.getifaddrs.map(&:addr).select(&:ipv4?).map(&:ip_address) - [\'127.0.0.1\']}"'
      }
    },
    notify => Class['fluentd::service']
  }

  fluentd::match { 'rewrite_dpkg_tag':
    priority => 40,
    pattern => sprintf('%s.dpkg', $tag),
    config => {
      '@type' => 'rewrite_tag_filter',
      rule => {
        key => 'message',
        pattern => '.+',
        tag => sprintf('%s.system.syslog', $tag)
      }
    }
  }

  # TEST3
  file { "/var/lib/ecp-veil/tests/node_init_test3.sh":
    ensure  => present,
    content => template("${module_name}/node_init_test3.sh.erb"),
    mode => '0550',
  }

}
