# configure grub
class veil_node::grub (
  Enum['on', 'off', 'pt'] $iommu_mode = 'off',
  Enum['downstream', 'downstream,multifunction', 'multifunction', ''] $pcie_acs_override = 'downstream'
) {

    file {'/etc/default/grub':
      notify  => Exec['update-grub2'],
    }

    file { "/etc/grub.d/10_linux":
      source => [ "/var/lib/ecp-veil/node/other/10_linux" ],
      owner  => root,
      group  => root,
      mode   => '0755',
    }
    exec { 'update-grub2':
      command     => '/usr/sbin/update-grub2',
      refreshonly => true,
    }

    kernel_parameter { "quiet":
      ensure   => present,
      bootmode => "default",
    }

    if $veil_node::grub::iommu_mode != 'off' {
      $intel_ensure = $facts['processor0'] ? {
        /(?i:^intel)/  => 'present',
        default        => 'absent',
      }
      $amd_ensure = $facts['processor0'] ? {
        /(?i:^amd|^advanced)/  => 'present',
        default                => 'absent',
      }
      if $veil_node::grub::pcie_acs_override and "${veil_node::grub::pcie_acs_override}".length > 0  {
        $pcie_acs_override_ensure = 'present'
      }
      else {
        $pcie_acs_override_ensure = 'absent'
      }
    }
    else {
      $intel_ensure             = 'absent'
      $amd_ensure               = 'absent'
      $pcie_acs_override_ensure = 'absent'
    }

    kernel_parameter { "intel_iommu":
      ensure   => $intel_ensure,
      bootmode => "default",
      value    => "${veil_node::grub::iommu_mode}"
    }

    kernel_parameter { "amd_iommu":
      ensure   => $amd_ensure,
      bootmode => "default",
      value    => "${veil_node::grub::iommu_mode}"
    }
    kernel_parameter { "iommu":
      ensure   => $amd_ensure,
      bootmode => "default",
      value    => "1"
    }

    kernel_parameter { "pcie_acs_override":
      ensure   => $pcie_acs_override_ensure,
      bootmode => "default",
      value    => "${veil_node::grub::pcie_acs_override}"
    }
# debug
# notice( "iommu_mode: ${veil_node::grub::iommu_mode}, intel: ${intel_ensure}, amd: ${amd_ensure}, pcie: ${veil_node::grub::pcie_acs_override}, pcie_ensure: ${pcie_acs_override_ensure} " )
}
