# configure environment to install node from .deb and dev repo
class veil_node {

  require veil_repos
  require veil_utils
  require veil_aide

  contain '::veil_node::nginx_node_inc'
  contain '::veil_node::install'
  contain '::veil_node::install_deps'
  contain '::veil_node::fluentd'
  contain '::veil_node::fluentd_user'
  contain '::veil_node::fluentd_install'
  contain '::veil_node::fluentd_config'
  contain '::veil_node::users'
  contain '::veil_node::dirs'
  contain '::veil_node::node_conf'
  contain '::veil_node::init_services'
  contain '::veil_node::rsyslog_severity'
  contain '::veil_node::first_boot'
  contain '::veil_node::kmod'
  contain '::veil_node::grub'
  contain '::veil_node::finalize'
  contain '::veil_node::lvm' ##removed since lvm2-2.03.00
  contain '::veil_node::multipath'
  contain '::veil_node::journalctl'
  contain '::veil_node::o2cb'
  contain '::veil_node::dlm'
  contain '::veil_node::consul'
  contain '::veil_node::minio'
  contain '::veil_node::lxc_conf'
  contain '::veil_node::lxc_conf'
  contain '::veil_node::nfs_server'

  Class['veil_node::nginx_node_inc'] ->
  Class['veil_node::node_conf'] ->
  Class['veil_node::install'] ->
  Class['veil_node::install_deps'] ->
  Class['veil_node::fluentd'] ->
  Class['veil_node::users'] ->
  Class['veil_node::dirs'] ->
  Class['veil_node::init_services'] ->
  Class['veil_node::first_boot'] ->
  Class['veil_node::kmod'] ->
  Class['veil_node::grub'] ->
  Class['veil_node::lvm'] -> ##removed since lvm2-2.03.00
  Class['veil_node::finalize'] ->
  Class['veil_node::multipath'] ->
  Class['veil_node::journalctl'] ->
  Class['veil_node::o2cb'] ->
  Class['veil_node::dlm'] ->
  Class['veil_node::consul'] ->
  Class['veil_node::minio'] ->
  Class['veil_node::lxc_conf']
  Class['veil_node::nfs_server'] ->

  file { "/usr/bin/crsh":
    ensure => absent,
  }
  $net_configured = find_file('/var/lib/ecp-veil/tests/net_configured')
  $veil_env = lookup('veil_env')
  $redis_db_password = lookup('redis_db_password')

  $file_path = '/etc/veil/veil_node_app_secret.key'
  $file_exists = find_file($file_path)
  if $file_exists  {
    notify{"File ${file_path} exist":}
    $secret_key = file("/etc/veil/veil_node_app_secret.key")
  } else {
    notify{"File ${file_path} does not exist":}
    exec { 'gen_veil_node_app_secret':
      command => "/usr/bin/openssl rand -base64 50 > /etc/veil/veil_node_app_secret.key",
      creates => "/etc/veil/veil_node_app_secret.key",
      path    =>  ["/usr/bin","/usr/sbin", "/bin"],
    }

    $secret_key = file("/etc/veil/veil_node_app_secret.key")
  }

  $veil_global_group = lookup('veil_global_group')
  $veil_node_user = lookup('veil_node_user')
  $veil_pgsql_db_user = lookup('veil_pgsql_db_user')
  $veil_pgsql_node_db_name = lookup('veil_pgsql_node_db_name')
  $veil_pgsql_port = lookup('veil_pgsql_port')
  $veil_pgbouncer_port = lookup('veil_pgbouncer_port')
  $pgsql_db_password = lookup('pgsql_db_password')

  file { "/var/log/veil/node/settings_local.py":
    ensure  => present,
    content => template("$module_name/settings_local.py.erb"),
  }

  exec { 'node_obfuscate':
    command => "/var/lib/ecp-veil/node/env/bin/pyarmor obfuscate --exact /var/log/veil/node/settings_local.py --output /var/lib/ecp-veil/node/bazalt --bootstrap 3",
    onlyif  => "test -f /var/log/veil/node/settings_local.py",
  }

  file { "/var/lib/ecp-veil/node/bazalt/settings_local.py":
    ensure  => present,
    mode    => '0644',
    owner => $veil_node_user,
    group => $veil_global_group,
  }

  if $net_configured {
    exec { "systemctl restart node_supervisor.service":
      subscribe   => File['/var/lib/ecp-veil/node/bazalt/settings_local.py'],
      refreshonly => true,
    }
  }
  if defined('$::is_node_no_controller') {
    if $is_node_no_controller == "1" {
      exec {"systemctl restart gunicorn-django-node.service":
        subscribe   => File['/var/lib/ecp-veil/node/bazalt/settings_local.py'],
        refreshonly => true,
      }
      exec { 'node_cli_obfuscate':
        command => "/var/lib/ecp-veil/cli/env/bin/pyarmor obfuscate --exact /var/log/veil/node/settings_local.py --output /var/lib/ecp-veil/cli/app",
        onlyif  => "test -f /var/log/veil/node/settings_local.py",
      }
    }
  }

  tidy { 'node_tmp_settings_local.py':
    path => '/var/log/veil/node/settings_local.py'
  }
}
