# configure environment to install controller from .deb and dev repo
class veil_node::init_services {

  $veil_ulogd2_ensure = lookup('veil_node::ulogd2_ensure')
  $veil_ttyd_ensure = lookup('veil_node::ttyd_ensure')
  $veil_linstor_ensure = lookup('veil_node::linstor_ensure')
  $veil_numad_ensure = lookup('veil_node::numad_ensure')
  
  file { "/lib/systemd/system/node_supervisor.service":
    source  => [
            "puppet:///modules/${module_name}/node_supervisor.service.${fqdn}",
            "puppet:///modules/${module_name}/node_supervisor.service",
    ],
    owner => 'root',
    group => 'root',
    mode => '0644',
  }
 file { "/lib/systemd/system/veil-mdev-recreate.service":
    source  => [
            "puppet:///modules/${module_name}/veil-mdev-recreate.service.${fqdn}",
            "puppet:///modules/${module_name}/veil-mdev-recreate.service",
    ],
    owner => 'root',
    group => 'root',
    mode => '0644',
  }
   file { "/lib/systemd/system/veil-watchdog.service":
    source  => [
            "puppet:///modules/${module_name}/veil-watchdog.service.${fqdn}",
            "puppet:///modules/${module_name}/veil-watchdog.service",
    ],
    owner => 'root',
    group => 'root',
    mode => '0644',
  }
  file { "/lib/systemd/system/ttyd.service":
    source  => [
            "puppet:///modules/${module_name}/ttyd.service.${fqdn}",
            "puppet:///modules/${module_name}/ttyd.service",
    ],
    owner => 'veil-node',
    group => 'veil-admins',
    mode => '0644',
  }
  file { "/lib/systemd/system/veil.slice":
    source => [
            "puppet:///modules/${module_name}/veil.slice.${fqdn}",
            "puppet:///modules/${module_name}/veil.slice",
    ],
    owner => 'root',
    group => 'root',
    mode => '0644',
  }
  # open-iscsi+10sec > veil-zfs-import > zfs-import.target > zfs-zed, zfs-mount > glusterd
  # zfs крашится при отсутствии незаменимых дисков в пулах, которые д.б. импортированы
  Service { 'zfs-import-cache':
    ensure => stopped,
    enable => false,
  }
  Service { 'veil-zfs-import':
    ensure => running,
  }
  file { "/etc/init.d/zfs-zed":
    ensure => absent,
  }
  file { "/lib/systemd/system/zfs-zed.service":
    source => [
      "puppet:///modules/${module_name}/zfs-zed.service.${fqdn}",
      "puppet:///modules/${module_name}/zfs-zed.service",
    ],
    owner => 'root',
    group => 'root',
    mode => '0644',
  }
  ~> Service { 'zfs-zed':
    ensure => running;
  }
  file { "/etc/systemd/system/zfs-mount.service":
    source => [
      "puppet:///modules/${module_name}/zfs-mount.service.${fqdn}",
      "puppet:///modules/${module_name}/zfs-mount.service",
    ],
    owner => 'root',
    group => 'root',
    mode => '0644',
  }
  ~> Service { 'zfs-mount':
    ensure => running;
  }
  file { "/lib/systemd/system/glusterd.service":
    source => [
      "puppet:///modules/${module_name}/glusterd.service.${fqdn}",
      "puppet:///modules/${module_name}/glusterd.service",
    ],
    owner => 'root',
    group => 'root',
    mode => '0644',
  }
  ~> Service { 'glusterd':
    ensure => running;
  }
  # lldpad order loop is fixed in 18441
  Service { 'lldpad.service':
    ensure => running,
    enable => true,
  }
  Service { 'lldpad.socket':
    ensure => running,
    enable => true,
  }
  if defined('$::is_node_no_controller') {
    if $is_node_no_controller == "1" {
      file { "/lib/systemd/system/gunicorn-django-node.service":
        source => [
          "puppet:///modules/${module_name}/gunicorn-django-node.service.${fqdn}",
          "puppet:///modules/${module_name}/gunicorn-django-node.service",
        ],
        owner  => 'root',
        group  => 'root',
        mode   => '0644',
      }
      file { "/lib/systemd/system/websockify-node.service":
        source => [
          "puppet:///modules/${module_name}/websockify-node.service.${fqdn}",
          "puppet:///modules/${module_name}/websockify-node.service",
        ],
        owner  => 'root',
        group  => 'root',
        mode   => '0644',
      }
      file { "/lib/systemd/system/gunicorn-proxy-node.service":
        source => [
          "puppet:///modules/${module_name}/gunicorn-proxy-node.service.${fqdn}",
          "puppet:///modules/${module_name}/gunicorn-proxy-node.service",
        ],
        owner  => 'root',
        group  => 'root',
        mode   => '0644',
      }
      file { "/lib/systemd/system/gunicorn-uploader-node.service":
        source => [
          "puppet:///modules/${module_name}/gunicorn-uploader-node.service.${fqdn}",
          "puppet:///modules/${module_name}/gunicorn-uploader-node.service",
        ],
        owner  => 'root',
        group  => 'root',
        mode   => '0644',
      }
      service { 'gunicorn-django-node':
        ensure => 'running',
        enable => true,
      }
      service { 'gunicorn-proxy-node':
        ensure => 'running',
        enable => true,
      }
      service { 'gunicorn-uploader-node':
        ensure => 'running',
        enable => true,
      }
      service { 'websockify-node.service':
        enable => true,
        ensure => 'running',
      }
    } else {
      exec { 'stop_gunicorn-django-node':
        command => "systemctl stop gunicorn-django-node; systemctl disable gunicorn-django-node",
        onlyif  => "systemctl is-active gunicorn-django-node.service>/dev/null",
        path    =>  ["/usr/bin","/usr/sbin", "/bin"],
      }
      exec { 'stop_gunicorn-proxy-node':
        command => "systemctl stop gunicorn-proxy-node; systemctl disable gunicorn-proxy-node",
        onlyif  => "systemctl is-active gunicorn-proxy-node.service>/dev/null",
        path    =>  ["/usr/bin","/usr/sbin", "/bin"],
      }
      exec { 'stop_gunicorn-uploader-node':
        command => "systemctl stop gunicorn-uploader-node; systemctl disable gunicorn-uploader-node",
        onlyif  => "systemctl is-active gunicorn-uploader-node.service>/dev/null",
        path    =>  ["/usr/bin","/usr/sbin", "/bin"],
      }
      exec { 'stop_websockify-node':
        command => "systemctl stop websockify-node; systemctl disable websockify-node",
        onlyif  => "systemctl is-active websockify-node.service>/dev/null",
        path    =>  ["/usr/bin","/usr/sbin", "/bin"],
      }
    }
  }
  service { 'ttyd':
    ensure => $veil_ttyd_ensure,
    enable => $veil_ttyd_ensure,
  }
  if $veil_node::net_configured {
    service { 'node_supervisor.service':
      ensure => 'running',
      enable => true,
    }
  }
 service { 'lvm2-lvmetad.service':
    enable => false,
    ensure => false,
  }
  service {'glusterd.service':
    ensure    => running,
    enable    => true,
  }
  # service {'drbd.service':
  #   ensure    => $veil_linstor_ensure,
  #   enable    => $veil_linstor_ensure,
  # }
  service {'linstor-satellite':
    ensure    => $veil_linstor_ensure,
    enable    => $veil_linstor_ensure,
  }
  service {'numad':
    ensure    => $veil_numad_ensure,
    enable    => $veil_numad_ensure,
  }
  service {'veil-mdev-recreate.service':
    ensure => false,
    enable => true,
  }
  service {'veil-watchdog.service':
    ensure => false,
    enable => true,
  }
  service { 'nftables.service':
    enable => true,
    ensure => false,
  }
  service { 'lxc-net.service':
    enable => false,
    ensure => false,
  }
  service { 'zfs-zed.service':
    enable => true,
    ensure => running,
  }
  service { 'prometheus-node-exporter-ipmitool-sensor.timer':
    enable => false,
    ensure => false,
  }
  service { 'ulogd2.service':
    enable => $veil_ulogd2_ensure,
    ensure => $veil_ulogd2_ensure,
  }
  # TEST4
  file { "/var/lib/ecp-veil/tests/node_init_test4.sh":
    ensure  => present,
    content => template("${module_name}/node_init_test4.sh.erb"),
    mode => '0550',
  }
  # TEST7
  file { "/var/lib/ecp-veil/tests/node_init_test7.sh":
    ensure  => present,
    content => template("${module_name}/node_init_test7.sh.erb"),
    mode => '0550',
  }
  file { '/var/lib/ecp-veil/node/bin/mdev-recreate':
    ensure  => present,
    source  => [ "puppet:///modules/${module_name}/mdev-recreate" ],
    mode    => '0755',
  }
  file { '/var/lib/ecp-veil/node/local_data/slices-tune.conf':
    ensure  => present,
    source  => [ "puppet:///modules/${module_name}/slices-tune.conf" ],
    owner => 'veil-node',
    group => 'veil-admins',
    mode    => '0664',
  }
  file { '/var/lib/ecp-veil/node/bin/slices-tune.py':
    ensure  => present,
    source  => [ "puppet:///modules/${module_name}/slices-tune.py" ],
    mode    => '0755',
  }
}
