# configure environment to install controller from .deb and dev repo
class veil_repos {

  include apt

  $veil_env = lookup('veil_env')
  $veil_extra = lookup('veil_extra')
  $veil_debian_release = lookup('veil_debian_release')
  $veil_repo_host = lookup('veil_repo_host')

  if $::osfamily == 'Altlinux' {
    file { "/etc/apt/sources.list.d/spacevm.list":
      content => template("$module_name/spacevm_rpm.list.erb"),
      owner   => 'root',
      group   => 'root',
      mode    => '0644',
    }
  } else {
    ensure_resource('package', 'apt-transport-https', { 'ensure' => 'present' })

    file { "/etc/apt/trusted.gpg.d":
      ensure => directory,
    }

    tidy { '/etc/apt/sources.list.d':
      recurse => 1,
      matches => [ 'ecp-veil.list', 'ecp-veil-extra.list' ]
    }

    file { "/etc/apt/sources.list.d/spacevm.list":
      content => template("$module_name/base_repo.list.erb"),
      owner   => 'root',
      group   => 'root',
      mode    => '0644',
    }

    file { "/etc/apt/sources.list.d/spacevm-extra.list":
      content => template("$module_name/extra_repo.list.erb"),
      owner   => 'root',
      group   => 'root',
      mode    => '0644',
    }

    file { "/etc/apt/trusted.gpg.d/veil-reprepro.gpg":
      source => [ "puppet:///modules/${module_name}/trusted.gpg.d/veil-reprepro.gpg" ],
      owner  => 'root',
      group  => 'root',
      mode   => '0644',
    }

    file { "/etc/apt/trusted.gpg.d/veil-aptly.gpg":
      source => [ "puppet:///modules/${module_name}/trusted.gpg.d/veil-aptly.gpg" ],
      owner  => 'root',
      group  => 'root',
      mode   => '0644',
    }

    file { "/etc/apt/trusted.gpg.d/veil-repo-key.gpg":
      source => [ "puppet:///modules/${module_name}/trusted.gpg.d/veil-repo-key.gpg" ],
      owner  => 'root',
      group  => 'root',
      mode   => '0644',
    }

    exec { "apt_update_space":
      command => "env DEBIAN_FRONTEND=noninteractive /usr/bin/apt-get update -y || true",
      onlyif  => "test -f /etc/apt/sources.list.d/spacevm.list",
    }
  }

}
