# configure environment to install controller from .deb and dev repo
class veil_utils::dirs {

  $veil_global_group = lookup('veil_global_group')
  $veil_controller_user = lookup('veil_controller_user')

  file { "/var/lib/ecp-veil":
    ensure => directory,
    mode => '0775',
    owner => $veil_controller_user,
    group => $veil_global_group,
  } ->
  file { "/var/lib/ecp-veil/run":
    mode => '0775',
    owner => $veil_controller_user,
    group => $veil_global_group,
    ensure => directory,
  } ->
  file { "/var/lib/ecp-veil/tests":
    ensure => directory,
    owner => $veil_controller_user,
    group => $veil_global_group,
    mode => '0770',
  } ->
  file { "/var/lib/ecp-veil/cli":
    ensure => directory,
    owner => $veil_controller_user,
    group => $veil_global_group,
    mode => '0775'
  } ->
  file { "/var/lib/ecp-veil/utils":
    ensure => directory,
    owner => $veil_controller_user,
    group => $veil_global_group,
    mode => '0755',
    recurse => true,
  } ->
  file { "/var/lib/ecp-veil/service_template":
    ensure => directory,
    owner => $veil_controller_user,
    group => $veil_global_group,
    mode => '0755',
    recurse => true,
  } ->
  file { "/var/lib/ecp-veil/controller_member":
    ensure => file,
    owner => $veil_controller_user,
    group => $veil_global_group,
    mode => '0755',
  } ->
  file { "/run/gunicorn":
    mode => '0777',
    ensure => directory,
  } ->
  file { "/etc/conf.d":
    ensure => directory,
  } ->
  file { "/etc/hosts.d":
    mode   => '0775',
    owner  => $veil_controller_user,
    group  => $veil_global_group,
    ensure => directory,
    recurse => true,
    recurselimit => 1,
  } ->
  file { "/etc/hosts.d.local":
    mode   => '0775',
    owner  => $veil_controller_user,
    group  => $veil_global_group,
    ensure => directory,
  } ->
  file { "/var/lib/ecp-veil/controller":
    owner => $veil_controller_user,
    group => $veil_controller_user,
    # mode for www-data access (todo: move www dir on top?)
    mode => '0775',
    ensure => directory,
  } ->
  file { "/var/lib/ecp-veil/controller/env":
    owner => $veil_controller_user,
    group => $veil_global_group,
    ensure => directory,
  } ->
  file { "/var/lib/ecp-veil/controller/app":
    owner => $veil_controller_user,
    group => $veil_global_group,
    ensure => directory,
  } ->
  file { "/var/lib/ecp-veil/controller/app/static":
    owner => $veil_controller_user,
    group => $veil_global_group,
    ensure => directory,
  } ->
  file { "/var/lib/ecp-veil/controller/app/static/screenshots":
    ensure  => directory,
    owner => $veil_controller_user,
    group => $veil_global_group,
    mode => '0755',
  } ->
  file { "/var/lib/ecp-veil/data":
    ensure => directory,
    owner => $veil_controller_user,
    group => $veil_global_group,
    mode => '0770',
  } ->
  file { "/var/lib/ecp-veil/data/modules":
    ensure => directory,
    owner => $veil_controller_user,
    group => $veil_global_group,
    mode => '0770',
  } ->
  file { "/var/lib/ecp-veil/data/local_modules":
    ensure => directory,
    owner => $veil_controller_user,
    group => $veil_global_group,
    mode => '0770',
    recurse => true,
    recurselimit => 1,
  } ->
  file { "/var/lib/ecp-veil/data/nodes":
    ensure => directory,
    owner => $veil_controller_user,
    group => $veil_global_group,
    mode => '0770',
  } ->
  file { "/var/log/veil":
    ensure => directory,
    owner => $veil_controller_user,
    group => $veil_global_group,
    mode => '0777',
    recurse => true,
    recurselimit => 1,
  } ->
    file { "/var/log/veil/controller":
    ensure => directory,
    owner => $veil_controller_user,
    group => $veil_global_group,
    mode => '0777',
    recurse => true,
    recurselimit => 1,
  } ->
  file { "/var/log/veil/controller/db_backup":
    ensure => directory,
    owner => $veil_controller_user,
    group => $veil_global_group,
    mode => '0777',
  } ->
  file { "/var/lib/ecp-veil/controller/local_data":
    ensure => directory,
    owner => $veil_controller_user,
    group => $veil_global_group,
    mode => '0777',
    recurse => true,
    recurselimit => 1,
  } ->
  file { "/var/lib/ecp-veil/controller/domains":
    ensure => directory,
    owner => $veil_controller_user,
    group => $veil_global_group,
    mode => '0777',
    recurse => true,
    recurselimit => 2,
  } ->
  file { "/var/log/veil/controller/journal":
    ensure => directory,
    owner => $veil_controller_user,
    group => $veil_global_group,
    mode => '0770',
  } ->
  file { "/var/log/veil/veil-role.log":
    mode => '0770',
    owner => $veil_controller_user,
    group => $veil_global_group,
  } ->
  file { "/var/lib/ecp-veil/utils/other/spectre-meltdown-checker.sh":
    mode => '0555',
    owner => $veil_controller_user,
    group => $veil_global_group,
    ensure  => file,
  } ->
  file { "/etc/systemd/system/libvirtd.service.d":
    owner  => root,
    group  => root,
    ensure => directory,
  } ->
  file { "/etc/systemd/system/libvirtd.service.d/cgroup-delegation.conf":
    source => [ "puppet:///modules/${module_name}/cgroup-delegation.conf" ],
    owner  => root,
    group  => root,
    mode   => '0644',
  } ->
  file { "/etc/sysconfig":
    owner  => root,
    group  => root,
    ensure => directory,
  }
  exec { 'chown_common_yaml':
    command => "chown $veil_controller_user:$veil_global_group /var/lib/ecp-veil/data/common.yaml",
    onlyif  => "test -f /var/lib/ecp-veil/data/common.yaml",
    path    =>  ["/usr/bin","/usr/sbin", "/bin"],
  }
}
