# manage system services
class veil_utils::services {
  service { 'puppet':
    ensure => stopped,
    enable => false,
  }
  service { 'mcollective':
    ensure => stopped,
    enable => false,
  }
  service { 'postgresql@13-main.service':
    ensure => running,
    enable => true,
  }
  file { "/lib/systemd/system/veil-dns.service":
    source  => [
            "puppet:///modules/${module_name}/veil-dns.service.${fqdn}",
            "puppet:///modules/${module_name}/veil-dns.service",
    ],
    owner => 'root',
    group => 'root',
    mode => '0644',
  }
  service { 'veil-dns.service':
    enable => true,
  }
  file { "/lib/systemd/system/veil-route.service":
    source  => [
            "puppet:///modules/${module_name}/veil-route.service.${fqdn}",
            "puppet:///modules/${module_name}/veil-route.service",
    ],
    owner => 'root',
    group => 'root',
    mode => '0644',
  }
  service { 'veil-route.service':
    enable => true,
  }
  service {'openvswitch-switch':
    ensure    => running,
    enable    => true,
  }
  service {'ovs-vswitchd':
    ensure    => stopped,
    enable    => mask,
  }
  service {'ovsdb-server':
    ensure    => stopped,
    enable    => mask,
  }
  file_line { "Streebog 1":
    path => '/etc/login.defs',
    line => 'ENCRYPT_METHOD GOST_YESCRYPT',
    match => '^ENCRYPT_METHOD',
  }
  file_line { "Streebog 2":
    path => '/etc/pam.d/common-password',
    line => 'password        [success=1 default=ignore]      pam_unix.so obscure gost-yescrypt',
    match => '^password.*pam_unix.so',
  }
  service { 'console-setup.service':
    enable => true,
    ensure => running,
  }
  file { '/etc/default/keyboard':
    ensure => present,
    source => [ "puppet:///modules/${module_name}/keyboard" ],
    mode => '0644',
    owner => 'root',
    notify => Service['console-setup.service'],
  }
  file { '/etc/default/console-setup':
    ensure => present,
    source => [ "puppet:///modules/${module_name}/console-setup" ],
    mode => '0644',
    owner => 'root',
    notify => Service['console-setup.service'],
  }
  # apparmor
  file { "/etc/apparmor.d/disable/":
    owner => root,
    group => root,
    ensure => directory,
  }
  file { '/etc/apparmor.d/disable/usr.lib.libvirt.virt-aa-helper':
    ensure => 'link',
    target => '/etc/apparmor.d/usr.lib.libvirt.virt-aa-helper',
    owner => root,
    group => root,
  }
  file { '/etc/apparmor.d/disable/usr.sbin.libvirtd':
    ensure => 'link',
    target => '/etc/apparmor.d/usr.sbin.libvirtd',
    owner => root,
    group => root,
  }
  service {'libvirtd':
    ensure    => running,
    enable    => true,
  }
  service {'auditd.service':
    ensure    => false,
    enable    => false,
  }
  service {'systemd-journald-audit.socket':
    ensure    => false,
    enable    => 'mask',
  }
}
