# Class: vsftpd
#
# Install, enable and configure a vsftpd FTP server instance.
#
# Parameters:
#  see vsftpd.conf(5) for details about what the available parameters do.
# Sample Usage :
#  include vsftpd
#  class { 'vsftpd':
#    anonymous_enable  => 'NO',
#    write_enable      => 'YES',
#    ftpd_banner       => 'Marmotte FTP Server',
#    chroot_local_user => 'YES',
#  }
#
class vsftpd (
  $ensure                  = 'running',
  $enable                  = true,
  $confdir                 = $::vsftpd::params::confdir,
  $package_name            = $::vsftpd::params::package_name,
  $service_name            = $::vsftpd::params::service_name,
  $local_root              = '/storages/',
  $template                = 'vsftpd/vsftpd.conf.erb',
  # vsftpd.conf options
  $anonymous_enable        = 'NO',
  $local_enable            = 'YES',
  $write_enable            = 'YES',
  $local_umask             = '022',
  $anon_upload_enable      = 'YES',
  $anon_mkdir_write_enable = 'YES',
  $dirmessage_enable       = 'YES',
  $xferlog_enable          = 'YES',
  $connect_from_port_20    = 'YES',
  $chown_uploads           = 'NO',
  $chown_username          = undef,
  $xferlog_file            = '/var/log/vsftpd.log',
  $xferlog_std_format      = 'YES',
  $idle_session_timeout    = '600',
  $data_connection_timeout = '120',
  $nopriv_user             = undef,
  $async_abor_enable       = 'NO',
  $ascii_upload_enable     = 'NO',
  $ascii_download_enable   = 'NO',
  $ftpd_banner             = 'Node FTP Server',
  $chroot_local_user       = 'YES',
  $chroot_list_enable      = 'NO',
  $chroot_list_file        = '/etc/vsftpd/chroot_list',
  $ls_recurse_enable       = 'NO',
  $listen                  = 'YES',
  $listen_port             = undef,
  $pam_service_name        = 'vsftpd',
  $userlist_enable         = 'YES',
  $userlist_deny           = 'NO',
  $tcp_wrappers            = 'YES',
  $hide_file               = undef,
  $hide_ids                = 'NO',
  $setproctitle_enable     = 'NO',
  $text_userdb_names       = 'NO',
  $max_clients             = undef,
  $max_per_ip              = undef,
  $pasv_min_port           = undef,
  $pasv_max_port           = undef,
  $ftp_username            = undef,
  $banner_file             = undef,
  $allow_writeable_chroot  = 'YES',
  $directives              = {
    'local_root' => $local_root
  },
) inherits ::vsftpd::params {

  package { $package_name: ensure => installed }

  service { $service_name:
    require   => Package[$package_name],
    enable    => $enable,
    ensure    => $ensure,
    hasstatus => true,
  }

  file { "${confdir}/vsftpd.conf":
    require => Package[$package_name],
    content => template($template),
    notify  => Service[$service_name],
  }

}

