#!/bin/sh

help()
{
	echo "$0 [-d dest_dir] [-t tgz_path ]"
	echo "E.g: $0 -d /tmp/pg_dump -t /tmp/pg_backup.tgz"
	exit 0
}

while getopts "d:t:h" opt; do
	case "$opt" in
		d) dest_dir="${OPTARG}" ;;
		h) help ;;
		t) tgz_path="${OPTARG}" ;;
	esac
done
shift $(($OPTIND - 1))

[ -z "${dest_dir}" ] && dest_dir="/tmp/pg_backup"
[ -z "${tgz_path}" ] && tgz_path="/tmp/pg_backup.tgz"

logfile=$( mktemp )
chmod 0666 ${logfile}
trap "rm -f ${logfile}" HUP INT ABRT BUS TERM EXIT

cat > /usr/local/etc/pg_backup.conf << EOF
data_directory = '${dest_dir}/main'
external_pid_file = '/tmp/postgres-test.pid'
port = 5434
max_connections = 5
#unix_socket_directory = '/var/run/postgresql'
ssl = false
shared_buffers = 24MB
log_line_prefix = '%t '
log_timezone = 'W-SU'
datestyle = 'iso, mdy'
timezone = 'W-SU'
lc_messages = 'en_US.UTF-8'
lc_monetary = 'en_US.UTF-8'
lc_numeric = 'en_US.UTF-8'
lc_time = 'en_US.UTF-8'
default_text_search_config = 'pg_catalog.english'
EOF

# postgresql area
if hash pg_lsclusters 2>/dev/null; then
	postgres_version=$( pg_lsclusters -h | head -n 1 | awk '{print $1}' )
	postgres_status=$( pg_lsclusters -h | head -n 1 | awk '{print $4}' )
	postgres_owner=$( pg_lsclusters -h | head -n 1 | awk '{print $5}' )
	pg_test_config="/usr/local/etc/pg_backup.conf"

	TS=$( date +%Y%m%d_%H%M%S )

	if  [ -d $dest_dir ]; then
		/bin/rm -rf ${dest_dir}
	fi

	mkdir -p -m 700 ${dest_dir}
	chown -R ${postgres_owner}:${postgres_owner} ${dest_dir}

	if [ $postgres_status = "online" ]; then
		/bin/su - $postgres_owner -c bash <<EOF
pg_basebackup -v -P -R -c fast -D ${dest_dir}/main -l $TS
/bin/cp /etc/postgresql/$postgres_version/main/pg_hba.conf ${dest_dir}/main/
/bin/cp /etc/postgresql/$postgres_version/main/pg_ident.conf ${dest_dir}/main/
/usr/lib/postgresql/$postgres_version/bin/postgres -D ${dest_dir}/main -c config_file=$pg_test_config > ${logfile} 2>&1 &
EOF
		if [ $? -ne 0 ]; then
			cat ${logfile}
			exit 1
		fi
	fi
fi
