#!/bin/bash

deb_subr="/usr/share/veil/deb.subr"

set -e
. ${deb_subr}
set +e

DEB_LOGFILE="/var/log/veil/first_boot.log"
# if memory (Mbytes) is more than this limit swap is turned off
MEM_SWAP_OFF=16000

configure_grub()
{
  LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Configure grub${NORMAL}"
  local _need_restart=0

	if replace_different -b /etc/default/grub.bak -s ${UTILS_CONFIG_DIR}/grub -d /etc/default/grub -o root -m 0644; then
		_need_restart=1
	fi
	if [ ${_need_restart} -eq 1 ]; then
	  LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Update grub${NORMAL}"
		update-grub
	fi
}

configure_timezone()
{
  tz=$( cat /etc/timezone )
  LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} save_timezone ${tz}${NORMAL}"

  echo "timezone::timezone: ${tz}" > ${LOCAL_MODULES_DIR}/timezone.yaml
}

collect_netinfo()
{
	
 	IP=$( grep address /etc/network/interfaces | awk '{print $2}' )
	LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Ip in collect_netinfo first_boot.sh - ${IP}${NORMAL}"
	GW=$( grep gateway /etc/network/interfaces | awk '{print $2}' )
    LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Gateway in collect_netinfo first_boot.sh - ${GW}${NORMAL}"
	NS=$( grep nameserver /etc/network/interfaces | awk '{$1=""; print $0}' | awk '{for(i=1;i<NF;i++)if(i!=NF){$i=$i","}}1' | sed 's/ //g' )
    LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Ns in collect_netinfo first_boot.sh - ${NS}${NORMAL}"
	MASK=$( grep netmask /etc/network/interfaces | awk '{print $2}' )
    LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Mask in collect_netinfo first_boot.sh - ${MASK}${NORMAL}"

	if $( echo ${IP} | grep -q '/' ); then
		IS_PREFIX=1
		MASK=
	else
		IS_PREFIX=0
		[ -z "${MASK}" ] && MASK="255.255.255.0"
	fi

	# [ -z "${NS}" ] && NS="8.8.8.8"

	IFACE=$( ip link | grep BROADCAST | grep -m 1 "state UP" | awk '{printf $2 " "}' | tr -d : )
	if [ -n "${IFACE}" ]; then
	  LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} First UP interface in collect_netinfo first_boot.sh - ${IFACE}${NORMAL}"
  else
	  IFACE=$( get_default_uplink )
	  LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} No UP interface! uplink interface ${IFACE} got by default${NORMAL}"
  fi

  VLANID=
  if [ -f "${BASE_DIR}/first_boot_vlan.conf" ]; then
    . ${BASE_DIR}/first_boot_vlan.conf
    rm ${BASE_DIR}/first_boot_vlan.conf
  fi

  LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} VLANID in collect_netinfo first_boot.sh - ${VLANID}${NORMAL}"
}

migrate_db ()
{
  if [ "$controller" -eq 1 ]; then
    echo $( date "+%Y-%m-%d-%H-%M-%S" ) >> ${CONTROLLER_LOGS_DIR}/create_db.log
    ${CONTROLLER_ENV_DIR}/bin/python ${CONTROLLER_APP_DIR}/manage.py migrate 2>&1 >> ${CONTROLLER_LOGS_DIR}/create_db.log
    _ret=$?
    if [ "$_ret" -ne 0 ]; then
      LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} controller migration failed with error code: ${_ret}${NORMAL}"
    else
      LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} controller migration completed successfully${NORMAL}"
    fi
  fi
  if [ "$node" -eq 1 ]; then
    echo $( date "+%Y-%m-%d-%H-%M-%S" ) >> ${NODE_LOGS_DIR}/create_db.log
    ${NODE_ENV_DIR}/bin/python ${NODE_DIR}/manage.py migrate 2>&1 >> ${NODE_LOGS_DIR}/migrate_node_db.log
    _ret=$?
    if [ "$_ret" -ne 0 ]; then
      LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} node migration failed with error code: ${_ret}${NORMAL}"
    else
      LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} node migration completed successfully${NORMAL}"
    fi
  fi
}

create_db ()
{
	if [ "$controller" -eq 1 ]; then
	  # check and create db
	  retval=$( sudo -u postgres psql -tc "SELECT 1 FROM pg_catalog.pg_database WHERE datname='${PGSQL_DB_NAME}';" 2>/dev/null )
    if [ ! -n "${retval}" ]; then
      echo "* ${LCYAN}${MY_APPLICATION}: ${WHITE}create db${NORMAL}" | tee ${CONTROLLER_LOGS_DIR}/create_db.log
      sudo -u postgres psql -c "CREATE DATABASE ${PGSQL_DB_NAME} WITH OWNER='${PGSQL_DB_USER}' LOCALE='en_US.UTF-8' ENCODING='UTF8' TEMPLATE='template0';" 2>&1 | tee -a ${CONTROLLER_LOGS_DIR}/create_db.log
    fi

	  # Сompile messages
		${CONTROLLER_ENV_DIR}/bin/python ${CONTROLLER_APP_DIR}/manage.py compilemessages  2>&1 >> ${CONTROLLER_LOGS_DIR}/compilemessages.log
		_ret=$?
		if [ "$_ret" -ne 0 ]; then
     	LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} controller compilemessages failed with error code: ${_ret}${NORMAL}"
		fi

		# Create first user
		echo "from django.contrib.auth.models import User; User.objects.create_superuser('${DEFAULT_UI_USER}', '${DEFAULT_UI_USER_EMAIL}', '${DEFAULT_UI_PASSWORD}')" | ${CONTROLLER_ENV_DIR}/bin/python ${CONTROLLER_APP_DIR}/manage.py shell 2>&1 >> ${CONTROLLER_LOGS_DIR}/create_db.log
		echo "from django.contrib.auth.models import Group, User; Group.objects.get_or_create(name='Superuser')[0].user_set.add(User.objects.get(username='admin')); Group.objects.get_or_create(name='Administrator')[0].user_set.add(User.objects.get(username='admin')); Group.objects.get_or_create(name='Security Administrator')[0].user_set.add(User.objects.get(username='admin'))" | ${CONTROLLER_ENV_DIR}/bin/python ${CONTROLLER_APP_DIR}/manage.py shell 2>&1 >> ${CONTROLLER_LOGS_DIR}/create_db.log
		
		admin_exist=$( 2>/dev/null env PGCONNECT_TIMEOUT=3 psql -t  postgresql://${PGSQL_DB_USER}:${PGSQL_DB_PASSWORD}@127.0.0.1:5432/${PGSQL_DB_NAME}?sslmode=disable <<EOF
select username from auth_user where username='admin' LIMIT 1;
EOF
	)
		[ ! -n "$admin_exist" ] && { LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} No controller admin user${NORMAL}"; return 3; }
	fi

	if [ "$node" -eq 1 ]; then
	  # check and create db
    retval=$( sudo -u postgres psql -tc "SELECT 1 FROM pg_catalog.pg_database WHERE datname='${PGSQL_NODE_DB_NAME}';" 2>/dev/null )
    if [ ! -n "${retval}" ]; then
      echo "* ${LCYAN}${MY_APPLICATION}: ${WHITE}create db${NORMAL}" | tee ${NODE_LOGS_DIR}/create_db.log
      sudo -u postgres psql -c "CREATE DATABASE ${PGSQL_NODE_DB_NAME} WITH OWNER='${PGSQL_DB_USER}' LOCALE='en_US.UTF-8' ENCODING='UTF8' TEMPLATE='template0';" 2>&1 | tee -a ${NODE_LOGS_DIR}/create_db.log
    fi

	  # Сompile messages
		${NODE_ENV_DIR}/bin/python ${NODE_DIR}/manage.py compilemessages  2>&1 >> ${NODE_LOGS_DIR}/compilemessages.log
		_ret=$?
		if [ "$_ret" -ne 0 ]; then
     	LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} node compilemessages failed with error code: ${_ret}${NORMAL}"
		fi

		# Create first user
		echo "from django.contrib.auth.models import User; User.objects.create_superuser('${DEFAULT_UI_USER}', '${DEFAULT_UI_USER_EMAIL}', '${DEFAULT_UI_PASSWORD}')" | ${NODE_ENV_DIR}/bin/python ${NODE_DIR}/manage.py shell 2>&1 >> ${NODE_LOGS_DIR}/create_db.log
		echo "from django.contrib.auth.models import Group, User; Group.objects.get_or_create(name='Superuser')[0].user_set.add(User.objects.get(username='admin')); Group.objects.get_or_create(name='Administrator')[0].user_set.add(User.objects.get(username='admin')); Group.objects.get_or_create(name='Security Administrator')[0].user_set.add(User.objects.get(username='admin'))" | ${NODE_ENV_DIR}/bin/python ${NODE_DIR}/manage.py shell 2>&1 >> ${NODE_LOGS_DIR}/create_db.log

		admin_exist=$( 2>/dev/null env PGCONNECT_TIMEOUT=3 psql -t  postgresql://${PGSQL_DB_USER}:${PGSQL_DB_PASSWORD}@127.0.0.1:5432/${PGSQL_NODE_DB_NAME}?sslmode=disable <<EOF
select username from auth_user where username='admin' LIMIT 1;
EOF
	)
		[ ! -n "$admin_exist" ] && { LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} No node admin user${NORMAL}"; return 3; }
	fi

	migrate_db
}

clear_logs ()
{
  LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Clear logs${NORMAL}"
  if [ "$node" -eq 1 ]; then
    [ -f "${NODE_LOGS_DIR}/node.log" ] && > ${NODE_LOGS_DIR}/node.log
  fi
  if [ "$controller" -eq 1 ]; then
    [ -f "${CONTROLLER_LOGS_DIR}/controller.log" ] && > ${CONTROLLER_LOGS_DIR}/controller.log
  fi
}

normal_exit ()
{
  [ -d "${BASE_DIR}/tests" ] && touch "${BASE_DIR}/tests/first_boot.passed"
  [ -d "${BASE_DIR}/tests" ] && touch "${BASE_DIR}/tests/net_configured"

  LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Exit without reboot${NORMAL}"
  exit 0
}

fix_permission ()
{
	if [ "$controller" -eq 1 ]; then
		LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Check file permission on controller${NORMAL}"

		chown -R ${CONTROLLER_SYS_USER}:${VEIL_GROUP} ${BASE_DIR} 
		chmod 0775 ${BASE_DIR}

		# controller settings
		chown -R ${CONTROLLER_SYS_USER}:${CONTROLLER_SYS_USER} ${CONTROLLER_DIR} ${SYS_USERS_DIR}/${CONTROLLER_SYS_USER} ${CONTROLLER_LOCAL_DATA_DIR}
		chmod 0775 ${CONTROLLER_DIR}
		chmod 0700 ${CONTROLLER_SYS_USER_SSH_CONF_DIR} ${CONTROLLER_LOCAL_DATA_DIR}
	fi

	if [ "$node" -eq 1 ]; then
		LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Check file permission on node${NORMAL}"
		chown -R ${NODE_SYS_USER}:${VEIL_GROUP} ${NODE_DIR} ${SYS_USERS_DIR}/${NODE_SYS_USER}
		chmod 0775 ${NODE_DIR}
		chmod 0700 ${NODE_SYS_USER_SSH_CONF_DIR} ${NODE_DIR}/bin ${PPT_NODE_CONFIG_DIR}
		chmod 600 ${NODE_SYS_USER_SSH_CONF_DIR}/config
	fi

}

swap_control () {
    local mem swp
    mem=$(cat /proc/meminfo | grep MemTotal: | awk '{ print $2 }')
    if [ ${mem} -gt $(( ${MEM_SWAP_OFF}*1000 )) ]; then
        LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE}Disabling swap because of enough RAM${NORMAL}"
        swapoff -a
        for swp in $(systemctl list-dependencies swap.target | grep \.swap$ | sed 's/^.*\(dev.*\)/\1/'); do
            systemctl mask ${swp}
        done
    fi
}

SKIP_NET=0
while getopts "s" opt; do
	case "$opt" in
		s) SKIP_NET=1 ;;
	esac
done
shift $((OPTIND - 1))

LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Start first boot ${NORMAL}"

if [ "$1" = "nonet" ]; then
	NONET=1
else
	NONET=0
fi

if [ -f /pxe.boot ]; then
	LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} PXE install ${NORMAL}"
	PXE=1
fi

controller=0
node=0

if [ ! -f "$VEIL_MEDIA_CONF" ]; then
	LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} No such ${VEIL_MEDIA_CONF} ${NORMAL}"
	return 1
fi

. "$VEIL_MEDIA_CONF"

configure_grub
configure_timezone
create_db
fix_permission
swap_control

# /tmp/nonet created by packer script
# i.e we work on vagrant
if [ -f /tmp/nonet ]; then
  LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} /tmp/nonet exists, skip first boot${NORMAL}"
  clear_logs
  normal_exit
fi

# last octet is dynamic from Vagrantfile
if $( ip a | grep 'link/ether' | grep -q 00:00:00:00:00: ); then
#	systemctl unmask veil-first-boot.service || true
#	systemctl disable veil-first-boot.service || true
#	rm -f /lib/systemd/system/veil-first-boot.service || true
	LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Vagrant box, skip first boot${NORMAL}"
	clear_logs
	normal_exit
fi

# openvswitch-switch post install action
systemctl status openvswitch-switch.service > /dev/null 2>&1
ret=$?

if [ "$ret" -ne 0 ]; then
	LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} First_boot error: systemctl status openvswitch-switch.service return $ret code${NORMAL}"
	exit ${ret}
fi

LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} openvswitch-switch.service configured successfully${NORMAL}"

# post-action veil-first-boot
#systemctl unmask veil-first-boot.service || true
#systemctl disable veil-first-boot.service || true
#rm -f /lib/systemd/system/veil-first-boot.service || true

LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Cron puppet configuration${NORMAL}"

[ ! -d /var/spool/cron/crontabs ] && mkdir -p /var/spool/cron/crontabs
cat > /var/spool/cron/crontabs/root <<EOF
# Puppet Name: puppetd
PATH=/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin:/opt/puppetlabs/bin
MAILTO=/dev/null
1 1 * * * nice -n 19 ionice -c 3 /usr/bin/flock -w0 -x /tmp/pa.lock /opt/puppetlabs/bin/puppet apply -d /etc/puppetveil/code/environments/production/manifests/site.pp --hiera_config=/etc/puppetveil/code/environments/production/hiera.yaml --modulepath=/etc/puppetveil/code/environments/production/modules > ${BASE_LOGS_DIR}/puppet.log 2>&1
# Puppet Name: puppet_boot
PATH=/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin:/opt/puppetlabs/bin
MAILTO=/dev/null
@reboot nice -n 19 ionice -c 3 /usr/bin/flock -w0 -x /tmp/pa.lock /opt/puppetlabs/bin/puppet apply /etc/puppetveil/code/environments/production/manifests/site.pp --hiera_config=/etc/puppetveil/code/environments/production/hiera.yaml --modulepath=/etc/puppetveil/code/environments/production/modules > ${BASE_LOGS_DIR}/puppet.log 2>&1
EOF

chmod 0600 /var/spool/cron/crontabs/root
chown root:crontab /var/spool/cron/crontabs/root

LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} System synchronization started${NORMAL}"

for i in $( seq 1 12 ); do
	nice -n 19 ionice -c 3 /usr/bin/flock -w0 -x /tmp/pa.lock /opt/puppetlabs/bin/puppet apply -d /etc/puppetveil/code/environments/production/manifests/site.pp --hiera_config=/etc/puppetveil/code/environments/production/hiera.yaml --modulepath=/etc/puppetveil/code/environments/production/modules > ${BASE_LOGS_DIR}/puppet.log
	LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Iteration ${i}, Errcode: $?${NORMAL}"
	# controller_node
	if [ ${controller} -eq 1 -a ${node} -eq 1 ]; then
    if [ -f /var/lib/ecp-veil/tests/node_init_finalize.passed ] && [ -f /var/lib/ecp-veil/tests/ctr_init_finalize.passed ]; then
      LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} All controller_node test passed on loop ${i}${NORMAL}"
      break
    else
      passed_tests=$( find /var/lib/ecp-veil/tests/ -name '*.passed' | sort )
      LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} controller_node passed tests on loop ${i}: \n${passed_tests}${NORMAL}"
    fi
	# node
	elif [ ${node} -eq 1 ]; then
    if [ -f /var/lib/ecp-veil/tests/node_init_finalize.passed ]; then
      LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} All node test passed on loop ${i}${NORMAL}"
      break
    else
      passed_tests=$( find /var/lib/ecp-veil/tests/ -name '*.passed' | sort )
      LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} node passed tests on loop ${i}: \n${passed_tests}${NORMAL}"
    fi
	elif [ ${controller} -eq 1 ]; then
    if [ -f /var/lib/ecp-veil/tests/ctr_init_finalize.passed ]; then
      LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} All controller test passed on loop ${i}${NORMAL}"
      break
    else
      passed_tests=$( find /var/lib/ecp-veil/tests/ -name '*.passed' | sort )
      LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} controller passed tests on loop ${i}: \n${passed_tests}${NORMAL}"
    fi    
  fi
done

LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} System last state synchronization started${NORMAL}"
/usr/local/sbin/veil-role -a full -d > ${BASE_LOGS_DIR}/puppet.log
LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Last synchronization errcode: $?${NORMAL}"

migrate_db

LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Network auto-configure started${NORMAL}"

IS_DHCP=0
IS_STATIC=0

if egrep -q dhcp /etc/network/interfaces; then
	IS_DHCP=1
	LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} DHCP network config ${NORMAL}"
fi

if egrep -q '([[:digit:]]{1,3}\.){3}[[:digit:]]{1,3}' /etc/network/interfaces; then
	IS_STATIC=1
	LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Static network config${NORMAL}"
fi

if [ "$IS_DHCP" -eq 0 -a "$IS_STATIC" -eq 0 ]; then
	IS_DHCP=1
fi

if [ "$NONET" -eq 1 ]; then
	LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Nonet, exit${NORMAL}"
	normal_exit
fi

collect_netinfo

DT=$( date "+%Y-%m-%d-%H-%M-%S" )

if [ "$SKIP_NET" -eq 1 ]; then
  LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Skip network configuration${NORMAL}"
  systemctl restart networking.service
  [ -d "${BASE_DIR}/tests" ] && touch "${BASE_DIR}/tests/net_configured"
  LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Restart networking errcode: $?${NORMAL}"
else
  if [ "$IS_STATIC" -eq 1 ]; then
    LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Static - variable is ${IS_STATIC}${NORMAL}"

    if [ -z "$GW" ]; then
      LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Gateway is empty${NORMAL}"
      # exit 1
    else
      LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Gateway in first_boot.sh in static configuration - ${GW}. Date - ${DT}${NORMAL}"
    fi
    if [ -z "$IP" ]; then
      LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Ip is empty${NORMAL}"
      exit 1
    else
      LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Ip in first_boot.sh in static configuration - ${IP}. Date - ${DT}${NORMAL}"
    fi

    LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Ip_prefix in first_boot.sh in static configuration - ${IS_PREFIX}. Date - ${DT}${NORMAL}"
    LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Mask in first_boot.sh in static configuration - ${MASK}. Date - ${DT}${NORMAL}"
    LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Iface in first_boot.sh in static configuration - ${IFACE}. Date - ${DT}${NORMAL}"

    if [ ${IS_PREFIX} -eq 1 ]; then
      LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} ${UTILS_CONFIG_DIR}/auto_configure_nic.sh -a init -f -m static -d ${NS} -g ${GW} -i ${IP} -u ${IFACE} -t 3 -w ${VLANID}${NORMAL}"
      ${UTILS_CONFIG_DIR}/auto_configure_nic.sh -a init -f -m static -d ${NS} -g ${GW} -i ${IP} -u ${IFACE} -t 3 -w ${VLANID}
      LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} auto_configure_nic errcode: $?${NORMAL}"
    else
      LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} ${UTILS_CONFIG_DIR}/auto_configure_nic.sh -a init -f -m static -d ${NS} -g ${GW} -i ${IP} -s ${MASK} -u ${IFACE} -t 3 -w ${VLANID}${NORMAL}"
      ${UTILS_CONFIG_DIR}/auto_configure_nic.sh -a init -f -m static -d ${NS} -g ${GW} -i ${IP} -s ${MASK} -u ${IFACE} -t 3 -w ${VLANID}
      LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} auto_configure_nic errcode: $?${NORMAL}"
    fi
  else
    LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} ${UTILS_CONFIG_DIR}/auto_configure_nic.sh -a init -m dhcp -u ${IFACE} -w ${VLANID}${NORMAL}"
    ${UTILS_CONFIG_DIR}/auto_configure_nic.sh -a init -m dhcp -u ${IFACE} -w ${VLANID}
  fi
fi

clear_logs

if [ ${controller} -eq 1 -a ${node} -eq 1 ]; then
  LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Restart controller services${NORMAL}"
  restart_services controller-supervisor gunicorn-proxy gunicorn-uploader gunicorn-ws websockify gunicorn-django daphne-django gunicorn-logger gunicorn-apiclient websockify

  LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Restart node on controller services${NORMAL}"
  restart_services node_supervisor
elif [ ${node} -eq 1 ]; then
  LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Restart only node services${NORMAL}"
  restart_services node_supervisor gunicorn-proxy-node gunicorn-django-node gunicorn-uploader-node
elif [ ${controller} -eq 1 ]; then
  LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Restart only controller services${NORMAL}"
  restart_services controller-supervisor gunicorn-proxy gunicorn-uploader gunicorn-ws websockify gunicorn-django daphne-django gunicorn-logger gunicorn-apiclient websockify
fi

systemctl is-active --quiet node_supervisor.service && LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE}Node supervisor active${NORMAL}" || LOG "* ${LCYAN}${MY_APPLICATION}: ${LRED}Node supervisor is not active!${NORMAL}"

normal_exit
